@@ -1,18 +1,19 @@
 package OpenInteract;
 
-# $Id: OpenInteract.pm,v 1.2 2001/02/06 22:08:53 lachoy Exp $
+# $Id: OpenInteract.pm,v 1.6 2001/06/01 01:41:01 lachoy Exp $
 
 use strict;
 use Apache::Constants qw( :common :remotehost );
 use Data::Dumper      qw( Dumper );
 
 @OpenInteract::ISA     = ();
-$OpenInteract::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 # Generic separator used in display
 
 my $SEP = '=' x 30;
 
+
 sub handler {
   my $apache = shift;
 
@@ -21,11 +22,10 @@ sub handler {
 
   my $R = eval { _setup_request( $apache ) };
   if ( $@ ) {
-    $apache->send_http_header( 'text/plain' );
-    $apache->print( $@ );
+    _send_html( $apache, $@ );
     return OK;
   }
-  $R->scrib( 1, "\n\n$SEP\nRequest started:", scalar localtime( $R->{time} ) );
+  $R->DEBUG && $R->scrib( 1, "\n\n$SEP\nRequest started:", scalar localtime( $R->{time} ) );
 
   # Go through all of our important steps -- we setup the basic
   # environment, generate the content and run additional routines after
@@ -49,16 +49,15 @@ sub handler {
     $page = _run_content_handler( $R );
     _finish_cookies_and_session( $R );
   }; 
-  return _bail( $@ )  if ( $@ );
+  if ( $@ ) {
+    warn " --EXITED WITH ERROR from main handler eval block.\n";
+    return _bail( $@ );
+  }
 
-  # Send the content
-  
   if ( $R->{page}->{send_file} ) { _send_static_file( $R ) }
-  else                           { _send_html( $R, $page ) }
+  else                           { _send_html( $apache, $page, $R ) }
 
-  # All done!
   _cleanup( $R );
-
   return OK;
 }
 
@@ -74,14 +73,18 @@ sub _bail {
 sub _setup_request {
   my ( $apache ) = @_;
 
-  # Read the stash class from our httpd.conf and grab the config object
-  
+  # Read the stash class from our httpd.conf and grab the config
+  # object
+
   my $STASH_CLASS   = $apache->dir_config( 'StashClass' );
- my $C             = $STASH_CLASS->get_stash( 'config' );
-  die "Cannot find configuration object! Big trouble!" unless ( $C );
+  my $C             = $STASH_CLASS->get_stash( 'config' );
+  unless ( ref $C and scalar keys %{ $C } ) {
+    die "Cannot find configuration object from stash class ($STASH_CLASS). Cannot continue!";
+  }
+
+  # Create the base request object that contains other objects and
+  # info
 
-  # Create the base request object that contains other objects and info
-  
   my $REQUEST_CLASS = $C->{request_class};
   my $R = $REQUEST_CLASS->instance;
   $R->{stash_class} = $STASH_CLASS;
@@ -104,10 +107,10 @@ sub _setup_apache {
 
   my $srv = $apr->server;
   $R->{server_name} = $srv->server_hostname;
-  $R->scrib( 1, "Server hostname set to $R->{server_name}" );
+  $R->DEBUG && $R->scrib( 1, "Server hostname set to $R->{server_name}" );
 
   $R->{remote_host} = $apr->connection->remote_ip();
-  $R->scrib( 1, "Request coming from $R->{remote_host}" );
+  $R->DEBUG && $R->scrib( 1, "Request coming from $R->{remote_host}" );
   return undef;
 }
 
@@ -122,7 +125,7 @@ sub _connect_to_database {
                                 extra => $R->CONFIG->{db_info} } );
     $R->scrib( 0, "Cannot connect to database! Immediately exiting process!" );
     my $error_msg = $R->throw( { code => 11 } );
-    _send_html( $R, $error_msg );
+    _send_html( $R->apache, $error_msg, $R );
     die OK . "\n";
   }
   $R->stash( 'db', $db );
@@ -130,7 +133,6 @@ sub _connect_to_database {
 }
 
 
-
 # Create the cache object if we're supposed to
 
 sub _setup_cache {
@@ -138,7 +140,7 @@ sub _setup_cache {
   my $C = $R->CONFIG;
   if ( ! $R->cache and $C->{cache_info}->{data}->{use} ) {   
     my $cache_class = $C->{cache_info}->{data}->{class};
-    $R->scrib( 1, "Using cache and setting up with ($cache_class)" );
+    $R->DEBUG && $R->scrib( 1, "Using cache and setting up with ($cache_class)" );
     my $cache = $cache_class->new( { config => $C } );
     $R->stash( 'cache', $cache );
   }
@@ -170,7 +172,7 @@ sub _parse_uri {
   my $path = $u->path;
   my @choices = split /\//, $path;
   shift @choices;
-  $R->scrib( 1, "Items in the path: ", join( " // ", @choices ) );
+  $R->DEBUG && $R->scrib( 1, "Items in the path: ", join( " // ", @choices ) );
   my @full_choices       = @choices;
   $R->{path}->{current}  = \@choices;
   $R->{path}->{full}     = \@full_choices;
@@ -183,14 +185,14 @@ sub _parse_uri {
     $path = '/' . join( '/', @{ $R->{path}->{current} } );
   }
   $R->{ui}->{action} = $R->{path}->{current}->[0];
-  $R->scrib( 1, "Action found from URL: $R->{ui}->{action}" );
+  $R->DEBUG && $R->scrib( 1, "Action found from URL: $R->{ui}->{action}" );
 
   # Note that $path might have been modified if the first item was a
   # directive
 
   $R->{path}->{original} = $path;
   $R->{path}->{original} .=  '?' . $u->query  if ( $u->query );
-  $R->scrib( 1, "Original path/query string set to: $R->{path}->{original}" );
+  $R->DEBUG && $R->scrib( 1, "Original path/query string set to: $R->{path}->{original}" );
   return undef;
 }   
 
@@ -203,35 +205,51 @@ sub _find_action_handler {
   ( $R->{ui}->{class}, $R->{ui}->{method} ) = $R->lookup_conductor( $R->{ui}->{action} ); 
   unless ( $R->{ui}->{class} ) {
     $R->scrib( 0, " Conductor not found; displaying oops page." );
-    eval { $R->throw( { code => 301, type => 'file',
-                        user_msg => "Bad URL",
+    eval { $R->throw( { code       => 301,
+                        type       => 'file',
+                        user_msg   => "Bad URL",
                         system_msg => "Cannot find conductor for $R->{ui}->{action}",
-                        extra => { url => $R->{path}->{original} } } ) };
+                        extra      => { url => $R->{path}->{original} } } ) };
     if ( $@ ) {
-      _send_html( $R, $@ );
+      _send_html( $R->apache, $@, $R );
       die OK . "\n";
     }
   }
-  $R->scrib( 1, "Found $R->{ui}->{class} // $R->{ui}->{method} for conductor" );
+  $R->DEBUG && $R->scrib( 1, "Found $R->{ui}->{class} // $R->{ui}->{method} for conductor" );
   return undef;
 }
 
 
 sub _setup_cookies_and_session {
   my ( $R ) = @_;
-  $R->cookies->parse;
-  $R->scrib( 2, "Cookies in:", Dumper( $R->{cookie}->{in} ) );
-  $R->session->parse;
+  eval {
+    $R->DEBUG && $R->scrib( 1, "Trying to use cookie class: ", $R->cookies );
+    $R->cookies->parse;
+    $R->DEBUG && $R->scrib( 2, "Cookies in:", Dumper( $R->{cookie}->{in} ) );
+    $R->DEBUG && $R->scrib( 1, "Trying to use session class: ", $R->session );
+    $R->session->parse;
+  };
+  if ( $@ ) { 
+    _send_html( $R->apache, $@, $R );
+    die OK . "\n";
+  }
   return undef;
 }
 
 
 sub _finish_cookies_and_session {
   my ( $R ) = @_;
-  $R->session->save;
-  $R->cookies->bake;
-  $R->scrib( 2, "Cookies out:", 
-                join(" // ", map { $_->name . ' = ' . $_->value } values %{ $R->{cookie}->{out} } ) );
+  eval {
+    $R->session->save;
+    $R->cookies->bake;
+    $R->DEBUG && $R->scrib( 2, "Cookies out:", 
+                  join(" // ", map { $_->name . ' = ' . $_->value } 
+                               values %{ $R->{cookie}->{out} } ) );
+  };
+  if ( $@ ) {
+    _send_html( $R->apache, $@, $R );
+    die OK . "\n";
+  }
   return undef;
 }
 
@@ -242,11 +260,17 @@ sub _setup_authentication {
   unless ( $R->auth ) {
     my $error_msg = "Authentication cannot be setup! Please ensure 'auth' is setup in your " .
                     "server configuration under 'system_alias'";
-    _send_html( $R, $error_msg );
-    return OK;
+    _send_html( $R->apache, $error_msg, $R );
+    die OK . "\n";
+  }
+  eval {
+    $R->auth->user;
+    $R->auth->group;
+  };
+  if ( $@ ) {
+    _send_html( $R->apache, $@, $R );
+    die OK . "\n";
   }
-  $R->auth->user;
-  $R->auth->group;
   return undef;
 }
 
@@ -265,10 +289,11 @@ sub _setup_theme {
   if ( $@ ) {
     OpenInteract::Error->set( SPOPS::Error->get );
     $R->throw( { code => 404 } );
-    $R->scrib( 0, "Error! Cannot retrieve theme! (Class: ", $R->theme, ") Help! $OpenInteract::Error::system_msg" );
+    $R->scrib( 0, "Error! Cannot retrieve theme! (Class: ", $R->theme, ") ",
+                  "Help! $OpenInteract::Error::system_msg" );
     my $error_msg = qq|Fundamental part of OpenInteract (themes) not functioning; please contact | .
                     qq|system administrator (<a href="mailto:$C->{admin_email}">$C->{admin_email}</a>).|;
-    _send_html( $R, $error_msg );
+    _send_html( $R->apache, $error_msg, $R );
     die OK . "\n";
   }
   return undef;
@@ -282,7 +307,7 @@ sub _setup_theme {
 sub _run_content_handler {
   my ( $R ) = @_;
   my ( $ui_class, $ui_method ) = ( $R->{ui}->{class}, $R->{ui}->{method} );
-  $R->scrib( 1, "Trying the conductor: <<$ui_class/$ui_method>>" );
+  $R->DEBUG && $R->scrib( 1, "Trying the conductor: <<$ui_class/$ui_method>>" );
   return $ui_class->$ui_method();
 }
 
@@ -301,7 +326,7 @@ sub _send_static_file {
     $R->scrib( 0, "Cannot open static file from filesystem ($static_file): $@" );
     return NOT_FOUND;
   }
-  $R->apache->send_http_header;
+  $R->apache->send_http_header( $R->{page}->{content_type} );
   $R->apache->send_fd( $fh );
   close( $fh );
 }
@@ -310,8 +335,8 @@ sub _send_static_file {
 # Send plain html (or text) to the browser
 
 sub _send_html {
-  my ( $R, $content ) = @_;
-  my $apache = $R->apache;
+  my ( $apache, $content, $R ) = @_;
+  $R ||= {};
   my $content_type = $R->{page}->{content_type} || $apache->content_type || 'text/html';
   $content_type = ( $content_type eq 'httpd/unix-directory' ) ? 'text/html' : $content_type;
   $apache->send_http_header( $content_type );
@@ -323,10 +348,10 @@ sub _send_html {
 
 sub _cleanup {
   my ( $R ) = @_;
-  $R->scrib( 2, "\n\nErrors: ", Dumper( $R->error_object->report ), "\n\n" );
+  $R->DEBUG && $R->scrib( 2, "\n\nErrors: ", Dumper( $R->error_object->report ), "\n\n" );
   $R->error->clear;
   $R->error_object->clear_listing;
-  $R->scrib( 1, "Request done at", scalar( localtime ), "from $R->{remote_host}\n$SEP\n" );
+  $R->DEBUG && $R->scrib( 1, "Request done at", scalar( localtime ), "from $R->{remote_host}\n$SEP\n" );
 
   # Ask the Request object to cleanup all its objects and finish
 
@@ -345,7 +370,7 @@ sub _setup_context {
   my ( $R ) = @_;
   if ( $R->CONFIG->{context}->{group} ) {
     my $context_id = $R->apache->param( 'gctxt' ) || $R->CONFIG->{default_objects}->{group};
-    $R->scrib( 1, "Creating group context using ID ($context_id)" );
+    $R->DEBUG && $R->scrib( 1, "Creating group context using ID ($context_id)" );
     $R->{context}->{group} = eval { $R->group->fetch( $context_id ) };
     if ( $@ ) {
       $R->scrib( 0, "Cannot create group (", $R->group, ":: $context_id) for context!",
