@@ -1,72 +1,77 @@
 package OpenInteract::Auth;
 
-# $Id: Auth.pm,v 1.3 2001/02/07 05:27:33 lachoy Exp $
+# $Id: Auth.pm,v 1.6 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 use Data::Dumper qw( Dumper );
 
 @OpenInteract::Auth::ISA     = ();
-$OpenInteract::Auth::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Auth::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+
+
+# Authenticate a user -- after calling this method if
+# $R->{auth}->{logged_in} is true then $R->{auth}->{user} will be a
+# user object.
 
 sub user {
-  my $class = shift;
+  my ( $class ) = @_;
   my $R = OpenInteract::Request->instance;
   if ( my $uid = $R->{session}->{user_id} ) {
-    $R->scrib( 1, "Found session and uid ($uid); creating user." );
+    $R->DEBUG && $R->scrib( 1, "Found session and uid ($uid); creating user." );
     
     # You MUST skip security here as a bootstrapping maneuver,
     # otherwise the superuser can never login (since WORLD has
     # SEC_LEVEL_NONE to the record)
     
-    $R->{auth}->{user} = eval { $R->user->fetch( $uid, { skip_security => 1 } ) };
+    $R->{auth}->{user} = eval { $R->user->fetch( $uid, 
+                                                 { skip_security => 1 } ) };
     
     # If there's a failure fetching the user, we need to ensure that
     # this user_id is not passed back to us again so we don't keep
-    # going through this
+    # going through this process...
     
     if ( $@ or ! $R->{auth}->{user} ) { 
       OpenInteract::Error->set( SPOPS::Error->get );
-      $R->throw( { code => 311 } );
+      $R->throw({ code => 311 });
       $R->{session}->{user_id} = undef;
       return undef;
     }
-    else  { 
       
-      # We use this to note that the user is logged in, since we'll
-      # shortly modify OI to create a record for a 'not-logged-in' user
-      # instead of leaving it empty.
+    # We use this to note that the user is logged in, since we'll
+    # shortly modify OI to create a record for a 'not-logged-in' user
+    # instead of leaving it empty.
+    
+    $R->{auth}->{logged_in} = 1;
       
-      $R->{auth}->{logged_in} = 1;
-      
-      $R->scrib( 2, "User: ", Dumper( $R->{auth}->{user} ) );
-      $R->scrib( 1, "User $R->{auth}->{user}->{login_name}" );
-      
-      # If there's a removal date, then this is the user's first
-      # login
+    $R->DEBUG && $R->scrib( 2, "User: ", Dumper( $R->{auth}->{user} ) );
+    $R->DEBUG && $R->scrib( 1, "User $R->{auth}->{user}->{login_name}" );
+    
+    # If there's a removal date, then this is the user's first
+    # login
 
-      if ( $R->{auth}->{user}->{removal_date} ) {
-        $R->scrib( 1, "First login for user! Do some cleanup." );
-        $R->{auth}->{user}->{removal_date} = undef;
+    if ( $R->{auth}->{user}->{removal_date} ) {
+      $R->DEBUG && $R->scrib( 1, "First login for user! Do some cleanup." );
+      $R->{auth}->{user}->{removal_date} = undef;
         
-        # blank out the removal date -- note that this doesn't seem to
-        # work properly, and put the user in the public group
+      # blank out the removal date -- note that this doesn't seem to
+      # work properly, and put the user in the public group
         
-        eval { 
-          $R->{auth}->{user}->save;         
-          $R->{auth}->{user}->make_public;  
-        };
-        # need to check for save/security errors here
-      }     
-    }
+      eval { 
+        $R->{auth}->{user}->save;         
+        $R->{auth}->{user}->make_public;  
+      };
+      # need to check for save/security errors here
+    }     
     return undef;
   }
-  $R->scrib( 1, "No uid found in session. Finding login info." );
+  $R->DEBUG && $R->scrib( 1, "No uid found in session. Finding login info." );
   
   # If the user didn't previously exist, try to create
   # from the fields login_name and password
 
   my $login_field    = $R->CONFIG->{login}->{login_field};
   my $password_field = $R->CONFIG->{login}->{password_field};
+  my $remember_field = $R->CONFIG->{login}->{remember_field};
   unless ( $login_field and $password_field ) {
     $R->throw({ code => 205, type => 'system' });
     return undef;
@@ -74,7 +79,7 @@ sub user {
 
   my $login_name = $R->apache->param( $login_field ); 
   return undef if ( ! $login_name );
-  $R->scrib( 1, "Found login name: <<$login_name>>" );
+  $R->DEBUG && $R->scrib( 1, "Found login name: <<$login_name>>" );
   my $user = eval { $R->user->fetch_by_login_name( $login_name, 
                                                    { return_single => 1,
                                                      skip_security => 1 } ) };
@@ -91,38 +96,43 @@ sub user {
   # Check the password
   
   my $password   = $R->apache->param( $password_field );
-  $R->scrib( 5, "Password entered: <<$password>>" );
+  $R->DEBUG && $R->scrib( 5, "Password entered: <<$password>>" );
   if ( ! $user->check_password( $password ) ) {
     $R->throw( { code => 402, type => 'authenticate', 
                  extra => { login_name => $login_name } } );
     return undef;
   }
-  $R->scrib( 1, "Passwords matched; creating new user." );
-  
-  # If the user was matched up to a login_name and the 
-  # password matched, put the user_id into the session
-  # and put the user into $R
+  $R->DEBUG && $R->scrib( 1, "Passwords matched; creating new user." );
 
+  # If the user was matched up to a login_name and the password
+  # matched, put the user_id into the session and put the user into
+  # $R. Also, make the expiration transient (expires when browser
+  # closes) unless the user clicked the 'Remember Me' checkbox
+
+  unless ( $R->apache->param( $remember_field ) ) {
+    $R->{session}->{expiration} = '';
+  }
   $R->{auth}->{logged_in} = 1;
   $R->{session}->{user_id} = $user->{user_id};
   $R->{auth}->{user} = $user; 
   return undef;
 }
 
-# Just create the groups this user belongs to
+
+# If the user is logged in, retrieve the groups he/she/it belongs to
 
 sub group {
-  my $class = shift;
+  my ( $class ) = @_;
   my $R = OpenInteract::Request->instance;
   unless ( $R->{auth}->{logged_in} ) {
-    $R->scrib( 1, "No logged-in user found, not retrieving groups." );
+    $R->DEBUG && $R->scrib( 1, "No logged-in user found, not retrieving groups." );
     return undef;
   }
-  $R->scrib( 1, "Authenticated user exists; getting groups." );
+  $R->DEBUG && $R->scrib( 1, "Authenticated user exists; getting groups." );
   $R->{auth}->{group} = eval { $R->{auth}->{user}->group };
   if ( $@ ) {
     OpenInteract::Error->set( SPOPS::Error->get );
-    $R->throw( { code => 309 } );
+    $R->throw({ code => 309 });
   }
   return undef;
 }
@@ -162,8 +172,9 @@ from it.
 
 =item 2.
 
-Find the $LOGIN_FIELD and $PASSWORD_FIELD arguments passed in and try
-to create a user with that login name and check the password.
+Find the $LOGIN_FIELD and $PASSWORD_FIELD arguments passed in via
+GET/POST and try to create a user with that login name and check the
+password.
 
 =back
 
