@@ -1,6 +1,6 @@
 package OpenInteract::Cache;
 
-# $Id: Cache.pm,v 1.1.1.1 2001/02/02 06:19:02 lachoy Exp $
+# $Id: Cache.pm,v 1.2 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 use Digest::MD5 qw( md5 );
@@ -32,7 +32,7 @@ sub get {
   my $R = OpenInteract::Request->instance;
   if ( ! $key and $p->{class} and $p->{id} ) {
     $key = $class->_make_idx( $p->{class}, $p->{id} );
-    $R->scrib( 1, "Created key from class/id: (($key))" );
+    $R->DEBUG && $R->scrib( 1, "Created key from class/id: (($key))" );
     $obj_class = $p->{class};
     $is_object++;
     return undef  unless ( $obj_class->pre_cache_get( $p->{id} ) );
@@ -50,7 +50,7 @@ sub get {
     $data = $data->{data};
   }
   return undef   if ( ! $data );
-  $R->scrib( 1, "Cache hit! for <<$key>>" );
+  $R->DEBUG && $R->scrib( 1, "Cache hit! for <<$key>>" );
   if ( $is_object ) {
     return undef  unless ( $obj_class->post_cache_get( $data ) );
   }
@@ -68,7 +68,7 @@ sub set {
   if ( $class->is_object( $data ) ) {
     $obj = $data;
     $key = $class->_make_idx( ref $obj, $obj->id );
-    $R->scrib( 1, "Created key from class/id: (($key))" );
+    $R->DEBUG && $R->scrib( 1, "Created key from class/id: (($key))" );
     $is_object++;
     return undef  unless ( $obj->pre_cache_save );
     if ( $obj->isa( 'SPOPS' ) ) {
@@ -125,7 +125,7 @@ sub size_bytes       { return undef; }
 sub DESTROY {
   my ( $self ) = shift;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Removing object ", ref $self, " from play." );
+  $R->DEBUG && $R->scrib( 1, "Removing object ", ref $self, " from play." );
 }
 
 1;
