@@ -1,6 +1,6 @@
 package OpenInteract::Cache::File;
 
-# $Id: File.pm,v 1.1.1.1 2001/02/02 06:19:13 lachoy Exp $
+# $Id: File.pm,v 1.2 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 use vars qw( $AUTOLOAD );
@@ -8,7 +8,7 @@ use File::Cache;
 use OpenInteract::Cache;
 
 @OpenInteract::Cache::File::ISA     = qw( OpenInteract::Cache );
-$OpenInteract::Cache::File::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Cache::File::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 
 $AUTOLOAD = undef;
 
@@ -56,7 +56,7 @@ sub class_initialize {
   my ( %extra );
   $extra{cache_depth} = $cache_depth  if ( $cache_depth );
 
-  $R->scrib( 1, "Using the following settings:\n   Size: $max_size\n", "   Expire: $max_expire\n   Dir: $cache_dir" );
+  $R->DEBUG && $R->scrib( 1, "Using the following settings:\n   Size: $max_size\n", "   Expire: $max_expire\n   Dir: $cache_dir" );
   my $cache = File::Cache->new( { expires_in => $max_expire, 
                                   max_size   => $max_size, 				  
                                   cache_key  => $cache_dir,
