@@ -1,13 +1,13 @@
 package OpenInteract::Cache::IPC;
 
-# $Id: IPC.pm,v 1.1.1.1 2001/02/02 06:19:14 lachoy Exp $
+# $Id: IPC.pm,v 1.2 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 use vars qw( $AUTOLOAD );
 use IPC::Cache;
 
 @OpenInteract::Cache::IPC::ISA     = ();
-$OpenInteract::Cache::IPC::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Cache::IPC::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 
 $AUTOLOAD = undef;
 
@@ -38,7 +38,7 @@ sub class_initialize {
   $max_expire ||= $DEFAULT_EXPIRE;
 
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Using the following settings:\n", "Expire: $max_expire\n   Key: $cache_key" );
+  $R->DEBUG && $R->scrib( 1, "Using the following settings:\n", "Expire: $max_expire\n   Key: $cache_key" );
   my $cache = IPC::Cache->new( { expires_in => $max_expire, 
                                  cache_key  => $cache_key } )
                || warn " (Cache/IPC): Cannot create cache!\n";
