@@ -1,6 +1,6 @@
 package OpenInteract::Error::Main;
 
-# $Id: Main.pm,v 1.2 2001/02/21 13:10:03 lachoy Exp $
+# $Id: Main.pm,v 1.4 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 require Exporter;
@@ -10,12 +10,10 @@ use Data::Dumper qw( Dumper );
 
 $ERROR_HOLD = 'error_hold';
 
-@OpenInteract::Error::Main::ISA     = ();
-$OpenInteract::Error::Main::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
-
+@OpenInteract::Error::Main::ISA       = qw( Exporter );
+$OpenInteract::Error::Main::VERSION   = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract::Error::Main::EXPORT_OK = qw( $ERROR_HOLD );
 
-use constant DEBUG => 0;
 
 sub catch {
   my ( $class, $err ) = @_;
@@ -24,7 +22,7 @@ sub catch {
  # Find the action and its error handlers 
 
   my $action = lc $err->{action};
-  $R->scrib( 1, "Action where the error was thrown from: <<$action>>" );
+  $R->DEBUG && $R->scrib( 1, "Action where the error was thrown from: <<$action>>" );
   my $MOD_INFO = $R->error_handlers;
   my $err_class_list = $MOD_INFO->{ $action } || [];
   push @{ $err_class_list }, $MOD_INFO->{'_DEFAULT_HANDLER'};
@@ -34,7 +32,7 @@ sub catch {
   # returns undef or any other false value.
 
   foreach my $err_class ( @{ $err_class_list } ) {
-    $R->scrib( 1, "See if class <<$err_class>> will take error" );
+    $R->DEBUG && $R->scrib( 1, "See if class <<$err_class>> will take error" );
     my $info = $err_class->can_handle_error( $err );
     next if ( ! $info or ! ref $info or ref $info ne 'CODE' );
     return $info->( $err );
@@ -55,7 +53,7 @@ sub initialize {
   $handler_info->{'_DEFAULT_HANDLER'} = $p->{config}->{default_error_handler};
   my $stash_class = $p->{config}->{stash_class};
   $stash_class->set_stash( 'error_handlers', $handler_info );
-  $R->scrib( 1, "Initialized DEFAULT_HANDLER for app $p->{stash_class} to $handler_info->{'_DEFAULT_HANDLER'}" );
+  $R->DEBUG && $R->scrib( 1, "Initialized DEFAULT_HANDLER for app $p->{stash_class} to $handler_info->{'_DEFAULT_HANDLER'}" );
 }
 
 sub save_error {
@@ -90,14 +88,18 @@ To do this, it needs to be able to determine a few things:
 
 =over 4
 
-=item * What type of error is this? The code (and possibly type)
-found in the error passed to I<catch()> should be sufficient to 
-distinguish errors from one another.
+=item *
 
-=item * From where was the error thrown? This is a crucial piece 
-of information, because it determines which set of error handlers 
-we inspect. We get this information from $R in the {current_context} 
-key. This key is either set by hand, or set when we call the 
+What type of error is this? The code (and possibly type) found in the
+error passed to I<catch()> should be sufficient to distinguish errors
+from one another.
+
+=item *
+
+From where was the error thrown? This is a crucial piece of
+information, because it determines which set of error handlers we
+inspect. We get this information from $R in the {current_context}
+key. This key is either set by hand, or set when we call the
 I<lookup_action()> method of $R.
 
 =back
@@ -137,8 +139,12 @@ including the handlers they intend to use for their errors.
 
 =head1 TO DO
 
+Nothing.
+
 =head1 BUGS
 
+None known.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001 intes.net, inc.. All rights reserved.
