@@ -1,14 +1,14 @@
 package OpenInteract::Error::System;
 
-# $Id: System.pm,v 1.2 2001/02/06 21:08:43 lachoy Exp $
+# $Id: System.pm,v 1.5 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
-use Carp                   qw( carp );
+use Carp                   qw( cluck );
 use Data::Dumper           qw( Dumper );
 use OpenInteract::Error::Main;
 
 @OpenInteract::Error::System::ISA     = ();
-$OpenInteract::Error::System::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Error::System::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 my $ERROR_HOLD = $OpenInteract::Error::Main::ERROR_HOLD;
 
@@ -42,7 +42,7 @@ $OpenInteract::Error::System::CODES = {
  '307' => \&cannot_retrieve_object_of_id,
  '308' => \&log_and_return,
  '309' => \&log_and_return,
- '310' => \&log_and_return,  
+ '310' => \&cannot_create_session,
  '311' => \&log_and_return,
  '312' => \&log_and_return,
  '313' => \&log_and_return,
@@ -87,7 +87,7 @@ sub can_handle_error {
 
 sub cannot_parse_config {
   my ( $err ) = @_;
-  carp ">> Error: Cannot open/parse config file. $err->{tmp_filename} / $err->{system_msg}" if ( DEBUG );
+  cluck ">> Error: Cannot open/parse config file. $err->{tmp_filename} / $err->{system_msg}" if ( DEBUG );
   $err->{notes} = "Filename tried to open: $err->{tmp_filename}";
   OpenInteract::Error::Main->save_error( $err );
   return '<h2 align="center">Website Down</h2>' .
@@ -102,7 +102,7 @@ sub cannot_parse_config {
 
 sub cannot_connect_db {
   my ( $err ) = @_;
-  carp ">> Error: Cannot connect to db. Info:\n", Dumper( $err->{tmp_db_info} ) if ( DEBUG );
+  cluck ">> Error: Cannot connect to db. Info:\n", Dumper( $err->{tmp_db_info} ) if ( DEBUG );
   my $R = OpenInteract::Request->instance;
   my $C = $R->CONFIG;
   $err->{error_id} = $err->generate_random_code( 16 ); 
@@ -145,7 +145,7 @@ MSG
 
 sub cannot_open_template {
   my ( $err ) = @_;
-  carp ">> Error: cannot open template. $err->{tmp_filename} / $err->{system_msg}" if ( DEBUG );
+  cluck ">> Error: cannot open template. $err->{tmp_filename} / $err->{system_msg}" if ( DEBUG );
   $err->{user_msg} = 'Could not open template file';
   $err->{notes} = "Filename tried to open: $err->{tmp_filename}";
   OpenInteract::Error::Main->save_error( $err );
@@ -154,7 +154,7 @@ sub cannot_open_template {
 
 sub cannot_parse_template {
   my ( $err ) = @_;
-  carp ">> Error: cannot parse template. $err->{tmp_filename} / $err->{system_msg}" if ( DEBUG );
+  cluck ">> Error: cannot parse template. $err->{tmp_filename} / $err->{system_msg}" if ( DEBUG );
   $err->{user_msg} = 'Could not process template';
   $err->{notes} = "Filename tried to open: $err->{tmp_filename} (if blank, we used text passed in)"; 
   OpenInteract::Error::Main->save_error( $err );
@@ -186,7 +186,7 @@ sub cannot_send_mail {
 
 sub cannot_open_template_db {
   my ( $err ) = @_;
-  carp ">> Error: cannot open template. $err->{tmp_name} / $err->{system_msg}" if ( DEBUG );
+  cluck ">> Error: cannot open template. $err->{tmp_name} / $err->{system_msg}" if ( DEBUG );
   $err->{user_msg} = 'Could not open template from database';
   $err->{notes} = "Tag tried to open with: $err->{tmp_name}";
   OpenInteract::Error::Main->save_error( $err );
@@ -195,7 +195,7 @@ sub cannot_open_template_db {
 
 sub cannot_find_login_fields {
   my ( $err ) = @_;
-  carp ">> Error: cannot find login/password fields!" if ( DEBUG );
+  cluck ">> Error: cannot find login/password fields!" if ( DEBUG );
   $err->{user_msg}   = 'No login/password fields specified!';
   $err->{system_msg} = "Please create entries in your 'conf/server.perl' file under " .
                        "the 'login->login_field' and 'login->password_field' keys. I cannot " .
@@ -209,7 +209,7 @@ sub cannot_find_login_fields {
 
 sub file_not_found {
   my ( $err ) = @_;
-  carp ">> Error: cannot find or open requested file: $err->{system_msg}"           if ( DEBUG );
+  cluck ">> Error: cannot find or open requested file: $err->{system_msg}"           if ( DEBUG );
   $err->{user_msg} = 'Requested file not found or cannot be opened';
   OpenInteract::Error::Main->save_error( $err );
   my $R = OpenInteract::Request->instance;
@@ -227,7 +227,7 @@ sub cannot_log_object_creation {
 
 sub task_is_forbidden {
   my ( $err ) = @_;
-  carp ">> Error: Cannot do task due to security: $err->{system_msg}"       if ( DEBUG );
+  cluck ">> Error: Cannot do task due to security: $err->{system_msg}"       if ( DEBUG );
   my $R = OpenInteract::Request->instance;
   my $html = $R->template->handler( {}, 
                                     { err => $err, 
@@ -240,7 +240,7 @@ sub task_is_forbidden {
 sub task_no_default {
   my ( $err ) = @_;
   $err->{user_msg} = 'No default method defined'; 
-  carp ">> Error: Cannot do task due to no default: $err->{system_msg}"     if ( DEBUG );
+  cluck ">> Error: Cannot do task due to no default: $err->{system_msg}"     if ( DEBUG );
   my $R = OpenInteract::Request->instance;
 
   # First send an email
@@ -266,7 +266,7 @@ sub task_no_default {
 
 sub task_not_allowed_security {
   my ( $err ) = @_;
-  carp ">> Error: Cannot accomplish task due to security."                  if ( DEBUG );
+  cluck ">> Error: Cannot accomplish task due to security."                  if ( DEBUG );
   my $R = OpenInteract::Request->instance;
   my $html = $R->template->handler( {}, 
                                     { err => $err,
@@ -278,7 +278,7 @@ sub task_not_allowed_security {
 
 sub cannot_retrieve_object_of_id {
   my ( $err ) = @_;
-  carp ">> Error: Cannot retrieve object given a particular ID."            if ( DEBUG );
+  cluck ">> Error: Cannot retrieve object given a particular ID."            if ( DEBUG );
   my $R = OpenInteract::Request->instance;
   
   # First send an email
@@ -301,11 +301,26 @@ given a particular ID. You might want to look into it.
   return undef;
 }
 
+
+sub cannot_create_session {
+  my ( $err ) = @_;
+  my $R = OpenInteract::Request->instance;
+  $R->scrib( 0, "Cannot create session -- someone is probably using a ",
+                "defunct key or something." );
+  $R->cookies->create_cookie({ 
+                 name => $OpenInteract::Session::COOKIE_NAME,
+                 path => '/',
+                 value => undef,
+                 expires => '-3d' });
+  return log_and_return( $err );
+}
+
+
 #400
 
 sub bad_username {
   my ( $err ) = @_;
-  carp ">> Error: User $err->{tmp_login_name} not found in system"          if ( DEBUG );
+  cluck ">> Error: User $err->{tmp_login_name} not found in system"          if ( DEBUG );
   my $R = OpenInteract::Request->instance;
   $R->{ $ERROR_HOLD }->{loginbox}->{bad_login} = "User $err->{tmp_login_name} not found!";
   return undef;
@@ -313,7 +328,7 @@ sub bad_username {
 
 sub bad_password {
   my ( $err ) = @_;
-  carp ">> Error: User $err->{tmp_login_name} login with wrong password"    if ( DEBUG );
+  cluck ">> Error: User $err->{tmp_login_name} login with wrong password"    if ( DEBUG );
   my $R = OpenInteract::Request->instance;
   $R->{ $ERROR_HOLD }->{loginbox}->{bad_login}  = "Bad password for $err->{tmp_login_name}; try again.";
   $R->{ $ERROR_HOLD }->{loginbox}->{login_name} = $err->{tmp_login_name};
@@ -324,10 +339,10 @@ sub bad_password {
 sub cannot_fetch {
   my ( $err ) = @_;
   if ( $err->{code} == 403 ) {
-    carp ">> Error thrown for not being able to fetch a group of objects. Msg: $err->{system_msg}";
+    cluck ">> Error thrown for not being able to fetch a group of objects. Msg: $err->{system_msg}";
   }
   elsif ( $err->{code} == 404 ) {
-    carp ">> Error thrown for not being able to fetch an object. Msg: $err->{system_msg}";
+    cluck ">> Error thrown for not being able to fetch an object. Msg: $err->{system_msg}";
   }
   return log_and_return( $err, 'nowarn' );
 }
@@ -346,9 +361,9 @@ sub cannot_fetch {
 
 sub log_and_return {
   my ( $err, $opt ) = @_;
-  carp ">> Error with code $err->{code} thrown. Info: $err->{system_msg}" unless ( $opt eq 'nowarn' );
+  cluck ">> Error with code $err->{code} thrown. Info: $err->{system_msg}" unless ( $opt eq 'nowarn' );
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 2, "Trying to save errror ", Dumper( $err ) );
+  $R->DEBUG && $R->scrib( 2, "Trying to save errror ", Dumper( $err ) );
   OpenInteract::Error::Main->save_error( $err );
   return undef;
 }
@@ -387,9 +402,13 @@ B<0-100>: emerg - system is unusable
 
 =over 4
 
-=item * 10: cannot_parse_config
+=item * 
 
-=item * 11: cannot_connect_db
+10: cannot_parse_config
+
+=item * 
+
+11: cannot_connect_db
 
 =back
 
@@ -397,7 +416,9 @@ B<100-199>: alert - action must be taken immediately
 
 =over 4
 
-=item * (none currently)
+=item * 
+
+(none currently)
 
 =back
 
@@ -558,10 +579,16 @@ OpenInteract modules will generate errors in this range
 
 =head1 METHODS
 
+Methods are all attached to various error codes.
+
 =head1 TO DO
 
+Nothing.
+
 =head1 BUGS
 
+None known.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001 intes.net, inc.. All rights reserved.
