@@ -1,6 +1,6 @@
 package OpenInteract::Handler::BasicPage;
 
-# $Id: BasicPage.pm,v 1.3 2001/02/06 22:10:42 lachoy Exp $
+# $Id: BasicPage.pm,v 1.9 2001/06/07 06:29:27 lachoy Exp $
 
 use strict;
 use SPOPS::Secure  qw( :level );
@@ -9,7 +9,7 @@ use Data::Dumper   qw( Dumper );
 use File::Basename qw();
 
 @OpenInteract::Handler::BasicPage::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure  );
-$OpenInteract::Handler::BasicPage::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::BasicPage::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::BasicPage::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::BasicPage::default_method    = 'listing';
@@ -30,7 +30,7 @@ my $MAIN_SCRIPT    = '/BasicPage';
 my $BODY_DEMARCATION = '<!-- OI BODY -->';
 
 # Use this to check whether the file retrieved is displayable in the
-# browser; others get sent to the user directly
+# browser; others (pdf, ps, mov, etc.) get sent to the user directly
 
 my %DISPLAY_TYPES = map { $_ => 1 } qw( '' html txt xml htm );
 
@@ -43,30 +43,32 @@ my $PAGE_SEPARATOR = '<!--PAGE-->';
 my $DEFAULT_EXPIRE = 60 * 60 * 24 * 7 * 52;
 
 
-
 # Overrides entry in OpenInteract::Handler::GenericDispatcher
 
 sub _get_task {
   my ( $class ) = @_;
   my $R = OpenInteract::Request->instance; 
   return 'show'  if ( $R->{path}->{full}->[0] ne 'BasicPage' );
-  return lc shift @{ $R->{path}->{current} } || $OpenInteract::Handler::BasicPage::default_method;
+  return lc shift @{ $R->{path}->{current} } 
+              || $OpenInteract::Handler::BasicPage::default_method;
 }
 
 
 
 # Retrieve all directories, expanding the one we were asked to (if at
-# all)
+# all). Note that these are just the objects in the database.
 
 sub listing {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
   my $selected_dir = $R->apache->param( 'selected_dir' );
   my $select_all = ( $selected_dir eq 'EXPANDALL' );
-  my $params = { main_script => $MAIN_SCRIPT, 
+  my $params = { main_script  => $MAIN_SCRIPT, 
                  selected_dir => $selected_dir, 
-                 error_msg => $p->{error_msg} };
-  my $page_list = eval { $R->static_page->fetch_group( { order => 'location' } ) };
+                 error_msg    => $p->{error_msg} };
+  my $page_list = eval { $R->static_page->fetch_group({ 
+                                             order        => 'location',
+                                             column_group => 'listing' }) };
   if ( $@ ) {
     Intereact::Error->set( SPOPS::Error->get );
     $R->throw( { code => 403 } );
@@ -77,12 +79,12 @@ sub listing {
   # listref of files it contains
 
   my %url_dir = ();
-  $R->scrib( 1, "Trying to find matches for ($selected_dir)" );
+  $R->DEBUG && $R->scrib( 1, "Trying to find matches for ($selected_dir)" );
   foreach my $page ( @{ $page_list } ) {
     my ( $base, $path, $suffix ) = File::Basename::fileparse( $page->{location} );
-    $R->scrib( 1, "Found ($path) ($base) in the page list" );
+    $R->DEBUG && $R->scrib( 1, "Found ($path) ($base) in the page list" );
     if ( $select_all or $path eq $selected_dir ) {
-      $R->scrib( 1, "Selected dir ($path) matched!" );
+      $R->DEBUG && $R->scrib( 1, "Selected dir ($path) matched!" );
       $page->{tmp_location} = $base;
       push @{ $url_dir{ $path } }, $page
     }
@@ -155,7 +157,7 @@ sub show {
     my $error_type = $@;
 
     unless ( $page_info or $do_edit ) {
-      $R->scrib( 1, "Creating new page or empty page info. Error type: ($error_type)" );
+      $R->DEBUG && $R->scrib( 1, "Creating new page or empty page info. Error type: ($error_type)" );
 
       # We have to force the content-type here because the user might
       # have requested a file that actually exists in the filesystem
@@ -186,7 +188,7 @@ sub show {
 
   if ( $page_info->{send_file} ) {
     $R->{page}->{send_file} = $page_info->{send_file};
-    $R->scrib( 1, "File being retrieved is not displayable. Set 'send_file' to $page_info->{send_file}" );
+    $R->DEBUG && $R->scrib( 1, "File being retrieved is not displayable. Set 'send_file' to $page_info->{send_file}" );
     return undef;
   }
 
@@ -214,7 +216,7 @@ sub show {
     # Ensure the page is viewable right now
     
     unless ( my $is_active = $class->_check_active_date( $page_info ) ) {
-      $R->scrib( 1, "Page has been marked as non-active ($is_active); returning error message." );
+      $R->DEBUG && $R->scrib( 1, "Page has been marked as non-active ($is_active); returning error message." );
       $R->{page}->{title} = 'Page not yet active';
       return '<h2 align="center">Not Active</h2>' . 
              '<p>Sorry, this page is not yet active.</p>';
@@ -258,7 +260,7 @@ sub edit {
   
   my $is_new = ( ! $location );
   
-  $R->scrib( 1, "Trying to modify location <<$location>>" );
+  $R->DEBUG && $R->scrib( 1, "Trying to modify location <<$location>>" );
   my $page = $p->{page};
   if ( $location ) {
     $page = eval { $R->static_page->fetch( $location ) };
@@ -285,14 +287,14 @@ sub edit {
   my %no_set = ( expires_on => 1, active_on => 1 );
   foreach my $field ( @{ $R->static_page->field_list } ) {
     next if ( $no_set{ $field } );
-    $R->scrib( 1, "Find value for field <<$field>>: ", $apr->param( $field ) );
+    $R->DEBUG && $R->scrib( 1, "Find value for field <<$field>>: ", $apr->param( $field ) );
     $page->{ $field } = $apr->param( $field );
   }
   
   $page->{active_on}  = $class->date_read( 'active_on' ) || $page->now();
   $page->{expires_on} = $class->date_read( 'expires_on' );
   unless ( $page->{expires_on} ) {
-    $R->scrib( 1, "Setting page's expiration time to the default, which is $DEFAULT_EXPIRE seconds after now." );
+    $R->DEBUG && $R->scrib( 1, "Setting page's expiration time to the default, which is $DEFAULT_EXPIRE seconds after now." );
     my $expire_time = $R->{time} + $DEFAULT_EXPIRE;
     my @time_info = localtime( $expire_time );
     $page->{expires_on} = join( '-', $time_info[5] + 1900, $time_info[4] + 1, $time_info[3] );
@@ -306,7 +308,7 @@ sub edit {
     $update_id = $location;
   }
   
-  $R->scrib( 1, "Contents of Page object before saving:\n", Dumper( $page ) );
+  $R->DEBUG && $R->scrib( 1, "Contents of Page object before saving:\n", Dumper( $page ) );
   my $rv = eval { $page->save( { is_add => $is_new, use_id => $update_id } ) };
   if ( $@ ) {
     my $ei = OpenInteract::Error->set( SPOPS::Error->get );
@@ -316,7 +318,7 @@ sub edit {
            'Cannot save document object! See error log for details.'
  }
 
-  $R->scrib( 1, "Document saved ok (Returned: $rv); returning to view of document." );
+  $R->DEBUG && $R->scrib( 1, "Document saved ok (Returned: $rv); returning to view of document." );
   $p->{static_page} = $page;
   return $class->show( $p ); 
 }
@@ -349,7 +351,7 @@ sub remove {
 sub _retrieve_object {
   my ( $class, $location ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to retrieve OBJECT with location ($location)" );
+  $R->DEBUG && $R->scrib( 1, "Trying to retrieve OBJECT with location ($location)" );
   
   # Chop off any query strings and put in a case-consistent format
   
@@ -357,11 +359,24 @@ sub _retrieve_object {
   $location    = lc $location;
   my $home_name = $R->CONFIG->{action}->{basicpage}->{object_home_name};
   
+  my @locations = ( $location );
   if ( $location =~ m|/$| ) {
-    $R->scrib( 1, "Trying to grab a directory; adding $home_name" );
-    $location .= $home_name;
+    $R->DEBUG && $R->scrib( 1, "Trying to grab a directory; adding $home_name" );
+    push @locations, "$location$home_name";
   }
-  my $page = eval { $class->_fetch_object( $location, "$location/$home_name" ) };
+  else {
+    $R->DEBUG && $R->scrib( 1, "Check to see if this is a directory request by adding /$home_name" );
+    push @locations, "$location/$home_name";
+  }
+
+  if ( $location =~ /\.\w+$/ ) {
+    my ( $sans_extension );
+    ( $sans_extension = $location ) =~ s/\.\w+$//;
+    $R->DEBUG && $R->scrib( 1, "Check location without the extension using $sans_extension" );
+    push @locations, $sans_extension;
+  }
+
+  my $page = eval { $class->_fetch_object( @locations ) };
   if ( $@ ) {
     my $ei = SPOPS::Error->get();
     warn " -- Found error when fetching object: ", Dumper( $ei ), "\n";
@@ -371,6 +386,13 @@ sub _retrieve_object {
 }
 
 
+# We might want to make this less sensitive -- we currently don't wrap
+# the 'fetch()' in an eval so errors bubble up, but maybe we should
+# catch the errors here and if all the tested locations result in
+# errors we bubble *that* up. For instance, what if requests 1 and 2
+# result in a security error but 3 doesn't? (Well... perhaps that
+# shouldn't happen in the first place :-)
+
 sub _fetch_object {
   my ( $class, @loc ) = @_;
   my $R = OpenInteract::Request->instance;
@@ -386,12 +408,12 @@ sub _fetch_object {
 sub _retrieve_file {
   my ( $class, $location ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to retrieve FILE with location ($location)" );
+  $R->DEBUG && $R->scrib( 1, "Trying to retrieve FILE with location ($location)" );
   $location = $class->_remove_query_string( $location );
   my $home_name = $R->CONFIG->{action}->{basicpage}->{filesystem_home_name};
   
   if ( $location =~ m|/$| ) {
-    $R->scrib( 1, "Trying to grab a directory; adding $home_name" );
+    $R->DEBUG && $R->scrib( 1, "Trying to grab a directory; adding $home_name" );
     $location .= $home_name;
   }
   my $page_info = $class->_fetch_file( $location, "$location/$home_name" );
@@ -413,42 +435,57 @@ sub _fetch_file {
   $html_dir =~ s|/$||;
   
   foreach my $location ( @loc ) {
-    
+
     # Security -- remove all '.' from the beginning of the location
-    # requested so people don't try to go up the directory tree
-    
+    # requested so people don't try to go up the directory tree. Also
+    # remove any two-dot sequence.
+    #
+    # In the future we might flag these as bad requests and simply
+    # bail with a stern warning.
+
     $location =~ s/^\.+//; 
+    $location =~ s/\.\./_/;
     
     my $full_location = join( '', $html_dir, $location );
     next unless ( -f $full_location );
-    $R->scrib( 1, "Filesystem location ($full_location) exists. Trying to read file." );
-    
-    # First check to see if this page is protected
-    
-    my $level = eval { SPOPS::Secure::Hierarchy->check_security({
-                               class => $R->basicpage, oid => $location,
-		                       user => $R->{auth}->{user}, 
-                               group => $R->{auth}->{group},
+    $R->DEBUG && $R->scrib( 1, "Filesystem location ($full_location) exists. Trying to read file." );
+
+    # First check to see if this page is protected by security -- if
+    # so, check it. If not, we set a default security level of 'WRITE'
+    # which will allow viewing
+
+    my $level = SEC_LEVEL_WRITE;
+    if ( $R->basicpage and $R->basicpage->isa( 'SPOPS::Secure' ) ) {
+      $R->DEBUG && $R->scrib( 1, "StaticPage object is protected by security. ",
+                    "Check security in filesystem." );
+      $level = eval { SPOPS::Secure::Hierarchy->check_security({
                                security_object_class => $R->security_object,
-                               hierarchy_separator => '/' }) };
-    $R->scrib( 0, "Error found checking security: $@" )  if ( $@ );
-    $R->scrib( 1, "Security found for ($location): ($level)" );
+                               class                 => $R->basicpage, 
+                               object_id             => $location,
+		                       user                  => $R->{auth}->{user}, 
+                               group                 => $R->{auth}->{group},
+                               hierarchy_separator   => '/' }) };
+      $R->scrib( 0, "Error found checking security: $@" )  if ( $@ );
+    }
+    $R->DEBUG && $R->scrib( 1, "Security found for ($location): ($level)" );
 
     die 'security' if ( $level < SEC_LEVEL_READ );
 
     # If the file extension isn't one we would normally display, treat
-    # it as a file we need to send to the user directly
+    # it as a file we need to send to the user directly.
 
     my ( $file_extension ) = $location =~ /\.(\w+)$/;
-    $R->scrib( 1, "File extension is ($file_extension)" );
+    $R->DEBUG && $R->scrib( 1, "File extension is ($file_extension)" );
     unless ( $DISPLAY_TYPES{ lc $file_extension } ) {
-      $R->scrib( 1, "File requested seems to NOT be one to display. Hopefully Apache ",
-                    "will know what kind of file this should be." );
+      $R->DEBUG && $R->scrib( 1, "File requested seems to NOT be one to display. ",
+                    "Hopefully Apache will know what kind of file ",
+                    "this should be." );
       $page_info->{send_file} = $full_location;
       return $page_info;
     }
 
-    $R->scrib( 1, "File requested can be displayed in the browser. Reading in..." );
+    $R->DEBUG && $R->scrib( 1, "File requested can be displayed in the browser. ",
+                  "Reading in the file..." );
     
     open( STATIC, $full_location ) || die "access";
     local $/ = undef;
@@ -469,18 +506,20 @@ sub _fetch_file {
     if ( $page_info->{pagetext} =~ s|<boxes>(.*)?</boxes>|| ) {
       $page_info->{boxes}    = $1;
     }
-    
-    # Only use the information between the $BODY_DEMARCATION tags (if they exist)
-    
+
+    # Only use the information between the $BODY_DEMARCATION tags (if
+    # they exist)
+
     $page_info->{pagetext} =~ s/$BODY_DEMARCATION(.*)?$BODY_DEMARCATION/$1/;
-    
-    # If the page still has <body> tags, only use the information between them
-    
+
+    # If the page still has <body> tags, only use the information
+    # between them
+
     $page_info->{pagetext} =~ s|<body>(.*)?</body>|$1|i;
     
     $page_info->{location} = $location;
     $page_info->{_filesystem} = $full_location;
-    $R->scrib( 2, "Page information being returned: ", Dumper( $page_info ) );
+    $R->DEBUG && $R->scrib( 2, "Page information being returned: ", Dumper( $page_info ) );
     return $page_info;
   }
   return undef;
@@ -587,11 +626,11 @@ sub _check_active_date {
     return 1;
   }
   
-  $R->scrib( 1, "Active on: $page_info->{active_on}; Expires on: $page_info->{expires_on}\n",
+  $R->DEBUG && $R->scrib( 1, "Active on: $page_info->{active_on}; Expires on: $page_info->{expires_on}\n",
                 "Active: $active_days; Now: $now_days; Expire: $expire_days" );
   return undef if ( $now_days < $active_days );
   return undef if ( $now_days > $expire_days );
-  $R->scrib( 1, "Page is active since $active_days < $now_days < $expire_days." );
+  $R->DEBUG && $R->scrib( 1, "Page is active since $active_days < $now_days < $expire_days." );
   return 1;
 }
 
@@ -615,13 +654,82 @@ something.
 
 =head1 METHODS
 
-=head1 TO DO
+=head2 PUBLIC
 
-B<Allow Multiple Directory Index Files>
+B<listing>
 
-Similar to Apache, allow 'home|index|default|...'
+List the page objects in the database.
 
-=head1 BUGS
+B<show>
+
+Display an individual page. Pass a positive value for the 'edit'
+parameter to be put into edit view for objects from the database.
+
+B<edit>
+
+Enter changes from objects being edited -- only to objects from the
+database.
+
+B<remove>
+
+Removes a page object from the database.
+
+=head2 PRIVATE
+
+B<_get_task>
+
+Override the C<_get_task()> method from
+L<OpenInteract::Handler::GenericDispatcher> so that this module can
+handle just about anything thrown at it and try to translate it as a
+page request.
+
+B<_retrieve_object>
+
+See if we can retrieve an object. If the request has a '/' at the end
+we append the 'home' name to the end. (The specific name is set in
+your action configuration.) If the request has a file extension we
+also test for the request without the file extension.
+
+B<_fetch_object>
+
+Try to fetch an object matching one of many locations.
+
+B<_retrieve_file>
+
+See if we can retrieve a file.
+
+B<_fetch_file>
+
+Try to open a file matchine one of many locations.
+
+B<_wrap_object>
+
+Wrap an the database object info so both the file and object appear
+the same once we have fetched them.
+
+B<_remove_query_string>
+
+Just strip the query string off the end.
+
+B<_split_pages>
+
+If the document is 'paged' (split into multiple documents using the
+character sequence $PAGE_SEPARATOR) then make the paging actually
+happen.
+
+B<_add_object_boxes>
+
+Add boxes from this page.
+
+B<_check_active_date>
+
+Ensure this page is active.
+
+=head1 SEE ALSO
+
+Please see the documentation for this package for the big picture,
+including TO DO items and other things. (Should be in
+C<../../../doc/package.pod>.)
 
 =head1 COPYRIGHT
 
