@@ -1,13 +1,13 @@
 package OpenInteract::Handler::Component;
 
-# $Id: Component.pm,v 1.2 2001/02/04 23:09:40 lachoy Exp $
+# $Id: Component.pm,v 1.5 2001/06/06 19:13:54 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper  qw( Dumper );
 
 @OpenInteract::Handler::Component::ISA     = ();
-$OpenInteract::Handler::Component::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Component::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Component::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Component::default_method    = 'handler';
@@ -34,17 +34,24 @@ sub handler {
   # template with the specified name
 
   unless ( scalar keys %{ $action_info } ) {
-    $R->scrib( 1, "No action info found; using name ($p->{name}) as template" );
+    $R->DEBUG && $R->scrib( 1, "No action info found; using name ($p->{name}) as template" );
     $action_info->{template} = $action_info->{name} = $p->{name};
     $action_info->{package}  = $p->{package};
   }
   unless ( $action_info->{template} or 
            $action_info->{class} or
            ref $action_info->{code} ) {
-    $R->scrib( 1, "No action info found; using name ($p->{name}) as template" );
+    $R->DEBUG && $R->scrib( 1, "No action info found; using name ($p->{name}) as template" );
     $action_info->{template} = $p->{name};
   }
-  $R->scrib( 2, "Action_info:\n", Dumper( $action_info ) );
+  $R->DEBUG && $R->scrib( 2, "Action_info:\n", Dumper( $action_info ) );
+
+  # If the template is a 'pkg::template' format, set the items properly
+
+  if ( $action_info->{template} =~ /^(.*)?::(.*)$/ ) {
+    $action_info->{package}  = $1;
+    $action_info->{template} = $2;
+  }
 
   $action_info->{package} ||= $action_info->{package_name};
 
@@ -53,7 +60,7 @@ sub handler {
   # whatever was passed in.
 
   my $params = ( ref $p->{params} ) ? $p->{params} : $p;
-  $R->scrib( 2, "Parameters being passed to component:\n", Dumper( $params ) );
+  $R->DEBUG && $R->scrib( 2, "Parameters being passed to component:\n", Dumper( $params ) );
 
   # Now that we have information for the component, go ahead and
   # process it -- output goes to $html. Note that if no component
@@ -66,7 +73,7 @@ sub handler {
   # Process the standalone template
 
   if ( $action_info->{template} ) {
-    $R->scrib( 1, "Generic template action with ($action_info->{template})" );
+    $R->DEBUG && $R->scrib( 1, "Generic template action with ($action_info->{template})" );
     $html = eval { $R->template->handler( {}, $params, 
                                           { db      => $action_info->{template}, 
                                             package => $action_info->{package} }) };
@@ -82,7 +89,7 @@ sub handler {
 
   elsif ( my $action_class = $action_info->{class} ) {
     $action_info->{method} ||= DEFAULT_METHOD;
-    $R->scrib( 1, "Calling component with $action_class->$action_info->{method}" );
+    $R->DEBUG && $R->scrib( 1, "Calling component with $action_class->$action_info->{method}" );
 
     # Check security unless explicitly told not to
 
@@ -95,7 +102,7 @@ sub handler {
     $html = eval { $action_class->$method( $params ) };
   }  
   $R->scrib( 0, "Died with error message: $@" )  if ( $@ );
-  $R->scrib( 2, "Component generated the following:\n$html" );
+  $R->DEBUG && $R->scrib( 2, "Component generated the following:\n$html" );
 
   # If they want the action information used by the component
   # (evidenced by requesting a list of information from the call) ,
@@ -120,13 +127,13 @@ sub _check_security {
     my %all_levels   = %{ $action_info->{class} . '::security' };
     $required_level = $all_levels{ $action_info->{method} } || NOTFOUND_SECURITY;
   }
-  $R->scrib( 1, "Checking security for component." );
+  $R->DEBUG && $R->scrib( 1, "Checking security for component." );
   my $current_level   = eval { $R->secure->check_security({ 
-                                              user => $R->{auth}->{user},
-                                              class => $action_info->{class}, 
-                                              oid => '0' }) };
+                                          user      => $R->{auth}->{user},
+                                          class     => $action_info->{class}, 
+                                          object_id => '0' }) };
   $current_level ||= SEC_LEVEL_WRITE;
-  $R->scrib( 1, "Target security: ($required_level); Actual: (current_level)" );
+  $R->DEBUG && $R->scrib( 1, "Target security: ($required_level); Actual: ($current_level)" );
   return ( $required_level, $current_level );
 }
 
