@@ -1,12 +1,12 @@
 package OpenInteract::Handler::Error;
 
-# $Id: Error.pm,v 1.1.1.1 2001/02/02 06:19:50 lachoy Exp $
+# $Id: Error.pm,v 1.4 2001/06/09 19:06:37 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::Error::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure );
-$OpenInteract::Handler::Error::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Error::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Error::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Error::default_method    = 'listing';
@@ -77,8 +77,9 @@ sub listing {
   # Now actually retrieve the errors 
 
   my $error_list = eval { $R->error_object->fetch_group({ 
-                                   order => $db_order, where => $where,
-                                   value => \@value }) };
+                                   order        => $db_order, 
+                                   where        => $where,
+                                   value        => \@value }) };
   if ( $@ ) {
     OpenInteract::Error->set( SPOPS::Error->get );
     $OpenInteract::Error::user_msg = 'Cannot retrieve list of errors.';
@@ -128,7 +129,7 @@ sub remove {
   my @error_id = $R->apache->param( 'error_id' );
   my ( @error_items );
   foreach my $eid ( @error_id ) {
-    $R->scrib( 1, "Removing error: $eid" );
+    $R->DEBUG && $R->scrib( 1, "Removing error: $eid" );
     my $error = eval { $R->error_object->fetch( $eid ); };
     if ( $@ or ! $error ) {
       push @error_items, "Could not retrieve error $eid to remove: $SPOPS::Error::system_msg" if ( $@ );
