@@ -1,17 +1,17 @@
 package OpenInteract::Handler::GenericDispatcher;
 
-# $Id: GenericDispatcher.pm,v 1.1.1.1 2001/02/02 06:19:17 lachoy Exp $
+# $Id: GenericDispatcher.pm,v 1.3 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( SEC_LEVEL_WRITE );
 
 use constant DEBUG => 0;
 
+
 # Note that we do "no strict 'refs'" a few times in various methods
 # throughout this packge -- it's just so we can refer to packge
 # variables properly.
 
-
 sub handler {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
@@ -23,7 +23,7 @@ sub handler {
 
   my $task = $p->{task} || $class->_get_task;
 
-  $R->scrib( 1, "Trying to run $class with $task" );
+  $R->DEBUG && $R->scrib( 1, "Trying to run $class with $task" );
 
   # Default is to email the author there is no default task defined.
 
@@ -33,7 +33,7 @@ sub handler {
   # die() with the content for the page
 
   unless ( $class->_task_allowed( $task ) ) {
-    $R->scrib( 1, "$task is forbidden by $class; bailing." );
+    $R->DEBUG && $R->scrib( 1, "$task is forbidden by $class; bailing." );
     $R->throw( { code => 303, type => 'module', extra => { task => $task } } );
   }
 
@@ -109,6 +109,7 @@ sub _task_allowed {
   return ! $forbidden{ $task };
 }
 
+
 sub _check_task_security {
   my ( $class, $task ) = @_;
   no strict 'refs';
@@ -129,7 +130,7 @@ sub _check_task_security {
     $level           = eval { $R->user->check_security( { class => $class, oid => '0' } ) };
     my %all_levels   = %{ $class . '::security' };
     my $target_level = $all_levels{ $task } || SEC_LEVEL_WRITE;
-    $R->scrib( 2, "Security after check for ($task):\n", "user has: $level; user needs: $target_level" );
+    $R->DEBUG && $R->scrib( 2, "Security after check for ($task):\n", "user has: $level; user needs: $target_level" );
 
     # Security check failed, so bail (error handler die()s with an error message
 
@@ -186,6 +187,7 @@ sub date_process {
 
 sub date_read {
   my ( $class, $prefix, $defaults ) = @_;
+  $defaults ||= {};
   my $apr = OpenInteract::Request->instance->apache;
   my $day   = $apr->param( "${prefix}_day" )   || $defaults->{day_default};
   my $month = $apr->param( "${prefix}_month" ) || $defaults->{month_default};
@@ -224,6 +226,9 @@ This module provides the routine 'handler' for you, which does all the
 routines (security checking and other) for you, then calls the proper
 method.
 
+There are also a couple of utility methods you can use, although they
+will probably be punted off to a separate module at some point.
+
 =head1 METHODS
 
 Even though there is only one primary method for this class, you may
@@ -275,12 +280,51 @@ actions. For instance, if you had a tag in every handler that was to
 be set in $R-E<gt>{page} and parsed by the main template to select a
 particular 'tab' on your web page, you could do so in this method.
 
-=back
+=head2 Utility
+
+B<_create_object( \%params )>
+
+Create an object from the information passed in via GET/POST and
+C<\%params>.
+
+Parameters:
+
+ _id_field: \@ or $ with field name(s) used to find ID value
+ _class:    $ with class of object to create
+
+Returns: object created with information, C<undef> if object ID not
+found, C<die> thrown if object class or ID field not given, or if the
+retrieval fails.
+
+B<date_process( 'yyyy-mm-dd' )>
+
+WARNING: This method might be removed altogether.
+
+Return a hashref formatted:
+
+ { year  => 'yyyy',
+   month => 'mm',
+   day   => 'dd' }
+
+B<date_read( $prefix, [ \%defaults ] )>
+
+Read in date information from GET/POST information. The fields are:
+
+ day    => ${prefix}_day
+ month  => ${prefix}_month
+ year   => ${prefix}_year
+
+If you want a default set for the day, month or year, pass the
+information in a hashref as the second argument.
 
 =head1 TO DO
 
+B<Move utility methods to separate class>
+
 =head1 BUGS
 
+None known.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001 intes.net, inc.. All rights reserved.
