@@ -1,23 +1,25 @@
 package OpenInteract::Handler::Logout;
 
-# $Id: Logout.pm,v 1.1.1.1 2001/02/02 06:19:17 lachoy Exp $
+# $Id: Logout.pm,v 1.3 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 
 @OpenInteract::Handler::Logout::ISA     = ();
-$OpenInteract::Handler::Logout::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Logout::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEBUG  => 0;
 
 sub handler {
   my ( $class ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->cookies->create_cookie({ name => $OpenInteract::Session::COOKIE_NAME,
-                               value => '', path => '/', expires => '-3d' });
+  $R->cookies->create_cookie({ name    => $OpenInteract::Session::COOKIE_NAME,
+                               value   => '', 
+                               path    => '/', 
+                               expires => '-3d' });
   my $return = $R->apache->param( 'return' );
-  $R->scrib( 1, "Logged out and trying to return to: ($return)" );
+  $R->DEBUG && $R->scrib( 1, "Logged out and trying to return to: <<$return>>" );
   my ( $action_class, $action_method ) = $R->lookup_action( 'redirect' );
-  return $action_class->$action_method( { url => $return } );
+  return $action_class->$action_method({ url => $return });
 }
 
 1;
@@ -44,8 +46,14 @@ None needed.
 
 =head1 METHODS
 
+B<handler()>
+
+Logs the current user out.
+
 =head1 TO DO
 
+Nothing.
+
 =head1 BUGS
 
 B<Set time somewhere?>
@@ -65,3 +73,4 @@ it under the same terms as Perl itself.
 Chris Winters <chris@cwinters.com>
 
 =cut
+<
