@@ -1,6 +1,6 @@
 package OpenInteract::Handler::NewUser;
 
-# $Id: NewUser.pm,v 1.1.1.1 2001/02/02 06:20:19 lachoy Exp $
+# $Id: NewUser.pm,v 1.2 2001/03/13 12:20:18 lachoy Exp $
 
 use strict;
 use Email::Valid;
@@ -8,7 +8,7 @@ use Data::Dumper  qw( Dumper );
 use SPOPS::Secure qw( :level :scope );
 
 @OpenInteract::Handler::NewUser::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::NewUser::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::NewUser::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::NewUser::default_method    = 'show';
@@ -84,9 +84,11 @@ sub edit {
  }
 
  # Ensure that the user can read/write his/her own record!
- eval { $R->user->set_item_security( { class => $R->user, oid => $new_uid,
-                                       scope => SEC_SCOPE_USER, scope_id => $new_user->{user_id},
-                                       level => SEC_LEVEL_WRITE } ) };
+ eval { $R->user->set_item_security({ class     => $R->user, 
+                                      object_id => $new_uid,
+                                      scope     => SEC_SCOPE_USER, 
+                                      scope_id  => $new_user->{user_id},
+                                      level     => SEC_LEVEL_WRITE }) };
 
  # Log the failed security set, if it happens...
  if ( $@ ) {
