@@ -1,13 +1,13 @@
 package OpenInteract::Handler::News;
 
-# $Id: News.pm,v 1.1.1.1 2001/02/02 06:20:32 lachoy Exp $
+# $Id: News.pm,v 1.4 2001/06/07 05:54:29 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper  qw( Dumper );
 
 @OpenInteract::Handler::News::ISA     = qw( OpenInteract::Handler::GenericDispatcher  SPOPS::Secure );
-$OpenInteract::Handler::News::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::News::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::News::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::News::default_method    = 'listing';
@@ -30,11 +30,10 @@ sub latest {
   my $params = { main_script => $MAIN_SCRIPT, error_msg => $p->{error_msg} };
   my $where = "active_on <= ? AND active = ? ";
   my @values = ( $R->news->now, 'yes' );
-  my $news_list = $class->_process_listing({ 
-                                  where => $where,
-                                  value => \@values });
+  my $news_list = $class->_process_listing({ where => $where,
+                                             value => \@values });
   @{ $params->{news_list} } = splice( @{ $news_list }, 0, $p->{num_items} );
-  return $R->template->handler( {}, $params, { db => 'news_latest',
+  return $R->template->handler( {}, $params, { db      => 'news_latest',
                                                package => 'news' } );
 }
 
@@ -55,28 +54,54 @@ sub listing {
     $where .= ' AND ( expires_on IS NULL OR expires_on > ? ) ';
   }
   push @values, $R->news->now;
-  $params->{news_list} = $class->_process_listing({
-                                         where => $where, 
-                                         value => \@values });
+  $params->{news_list} = $class->_process_listing({ where => $where, 
+                                                    value => \@values });
 
  $R->{page}->{title} = 'News Items';
- return $R->template->handler( {}, $params, { db => 'news_list',
+ return $R->template->handler( {}, $params, { db      => 'news_list',
                                               package => 'news' } );
 }
 
 
+sub _generate_date_format {
+  my ( $class, $command, $field, $formats ) = @_;
+  $command =~ s/%%FIELD%%/$field/g;
+  foreach my $fmt_key ( keys %{ $formats } ) {
+    $command =~ s/\%\%$fmt_key\%\%/$formats->{ $fmt_key }/g;
+  }
+  return $command;
+}
+
 
 sub _process_listing {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Processing news listing with ($p->{where})" );
-  my $date_format = { posted_on => "DATE_FORMAT( posted_on, '%a %b %d %h:%i %p' )",
-                      expires_on => "DATE_FORMAT( expires_on, '%a %b %d %h:%i %p' )" };
+  $R->DEBUG && $R->scrib( 1, "Processing news listing with ($p->{where})" );
+
+  # Deal with date goop -- if this works ok we'll move it to a utility
+  # method somewhere
+
+  my $date_fmt     = {};
+  if ( $p->{use_date_format} ) {
+    my $args = {};
+    my ( $date_command );
+    if ( $p->{use_date_format} eq 'mysql' ) {
+      $date_command = q/DATE_FORMAT( %%FIELD%%, '%%FORMAT%%' )/;
+      my $date_default = $p->{default_date_format} || '%a %b %d %h:%i %p';
+      $args = { FORMAT => $date_default };
+    }
+    $date_fmt->{posted_on}  = $p->{posted_on_format} ||
+                              $class->_generate_date_format( $date_command, 'posted_on', $args );
+    $date_fmt->{expires_on} = $p->{expires_on_format} ||
+                              $class->_generate_date_format( $date_command, 'expires_on', $args );
+  }
+  my $order = $p->{order} || 'posted_on DESC';
   my $news_list = eval { $R->news->fetch_group({
-                                      where => $p->{where},
-                                      value => $p->{value}, 
-                                      field_alter => $date_format,
-                                      order => 'posted_on DESC' }) };
+                                      where        => $p->{where},
+                                      value        => $p->{value}, 
+                                      field_alter  => $date_fmt,
+                                      limit        => $p->{limit},
+                                      order        => $order  }) };
   if ( $@ ) {
     OpenInteract::Error->set( SPOPS::Error->get );
     $R->throw( { code => 403 } );
@@ -94,10 +119,14 @@ sub _process_listing {
     # If there is template content in the news item, process it
     
     if ( $news->{tmp_content} =~ m|\[\%| ) {
-      $R->scrib( 1, "Processing template directive content for news item ($news->{title})" );
+      $R->DEBUG && $R->scrib( 1, "Processing template directive content for news item ($news->{title})" );
       $news->{tmp_content} = $R->template->handler( {}, {}, 
                                                     { text => $news->{tmp_content} } );
     }
+
+    # Now grab relevant user information, caching as we go (since the
+    # same people tend to post news)
+
     unless ( $posters{ $news->{posted_by} } ) {
       my $user = eval { $news->posted_by_user() };
       my $poster_info = {};
@@ -226,7 +255,7 @@ sub edit {
   my %no_read = ( posted_by => 1, expires_on => 1, active_on => 1, news_id => 1 );
   foreach my $field ( @{ $R->news->field_list } ) {
     next if ( $no_read{ $field } );
-    $R->scrib( 1, "Find value for field <<$field>>" );
+    $R->DEBUG && $R->scrib( 1, "Find value for field <<$field>>" );
     $news->{ $field } = $apr->param( $field );
   }
 
@@ -276,7 +305,7 @@ sub remove {
   eval { $news->remove };
   if ( $@ ) {
     my $ei = OpenInteract::Error->set( SPOPS::Error->get );
-    $R->scrib( 1, "Cannot remove News: $@\n", Dumper( $ei ) );
+    $R->DEBUG && $R->scrib( 1, "Cannot remove News: $@\n", Dumper( $ei ) );
     $R->throw( { code => 405 } );
     $p->{error_msg} = "Cannot remove news object! See error log.";
   }
