@@ -1,13 +1,13 @@
 package OpenInteract::Handler::Package;
 
-# $Id: Package.pm,v 1.2 2001/02/20 04:14:28 lachoy Exp $
+# $Id: Package.pm,v 1.4 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper  qw( Dumper );
 
 @OpenInteract::Handler::Package::ISA               = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure );
-$OpenInteract::Handler::Package::VERSION           = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Package::VERSION           = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::Package::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Package::default_method    = 'listing';
 @OpenInteract::Handler::Package::forbidden_methods = ();
@@ -16,7 +16,7 @@ $OpenInteract::Handler::Package::default_method    = 'listing';
  edit    => SEC_LEVEL_WRITE, remove => SEC_LEVEL_WRITE,
 );
 
-use constant DEBUG => 1;
+use constant DEBUG => 0;
 
 my $MAIN_SCRIPT = '/Package';
 
@@ -26,12 +26,13 @@ my $MAIN_SCRIPT = '/Package';
 sub listing {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $params = { main_script => $MAIN_SCRIPT, error_msg => $p->{error_msg} };
+  my $params = { main_script => $MAIN_SCRIPT, 
+                 error_msg   => $p->{error_msg} };
 
   # First retrieve the packages from this app
 
   my $website_dir = $R->CONFIG->{dir}->{base};
-  $R->scrib( 1, "Trying to open repository in website dir ($website_dir)" );
+  $R->DEBUG && $R->scrib( 1, "Trying to open repository in website dir ($website_dir)" );
   my $website_repository  = $R->repository->fetch( 
                                      undef, { directory => $website_dir } );
   $params->{website_pkg}  = $website_repository->fetch_all_packages();
@@ -39,13 +40,13 @@ sub listing {
   # Next, retrieve the packages from base installation
 
   my $base_install_dir = $R->CONFIG->{dir}->{interact};
-  $R->scrib( 1, "Trying to open repository in base installation dir ($base_install_dir)" );
+  $R->DEBUG && $R->scrib( 1, "Trying to open repository in base installation dir ($base_install_dir)" );
   my $base_repository     = $R->repository->fetch( 
                                      undef, { directory => $base_install_dir } );
   $params->{interact_pkg} = $base_repository->fetch_all_packages();
   $R->{page}->{title} = "Package Listing";
-  return $R->template->handler( {}, $params, 
-                                { db => 'package_listing', package => 'base' } );
+  return $R->template->handler( {}, $params, { db      => 'package_listing', 
+                                               package => 'base' } );
 }
 
 
@@ -55,7 +56,8 @@ sub listing {
 sub show {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $params = { main_script => $MAIN_SCRIPT, error_msg => $p->{error_msg} };
+  my $params = { main_script => $MAIN_SCRIPT, 
+                 error_msg   => $p->{error_msg} };
   my $do_edit = ( $R->apache->param( 'edit' ) and $p->{level} >= SEC_LEVEL_WRITE );
 
   $params->{scope} = $R->apache->param( 'scope' ) || 'local';
@@ -67,7 +69,7 @@ sub show {
   my $name    = $R->apache->param( 'name' );
   my $version = $R->apache->param( 'version' );
   my $pkg = $p->{pkg} || 
-            $repository->fetch_package_by_name({ name => $name, 
+            $repository->fetch_package_by_name({ name    => $name, 
                                                  version => $version });
   unless ( $pkg ) {
     my $error_msg = "Sorry, couldn't find a package matching the criteria you specified.";
@@ -77,7 +79,7 @@ sub show {
     $params->{error_msg} .= "Found a working package, but it wasn't the version you requested.";
   }
   $params->{pkg} = $pkg;
-  return $R->template->handler( {}, $params, { db => 'package_detail', 
+  return $R->template->handler( {}, $params, { db      => 'package_detail', 
                                                package => 'base' } );
 }
 
@@ -92,7 +94,7 @@ sub edit {
   my $repository = $R->repository->fetch( undef, { directory => $base_dir,
                                                    perm      => 'write' } );
   
-  my $pkg = $repository->fetch_package_by_name({ name => $name, 
+  my $pkg = $repository->fetch_package_by_name({ name    => $name, 
                                                  version => $version });
   if ( $@ or ! $pkg ) {
     my $error = $@ || "No package found using $name-$version";
@@ -133,17 +135,34 @@ __END__
 
 OpenInteract::Handler::Package - Allow viewing/editing of package information in base and website
 
-=head1 SYNOPSIS
-
 =head1 DESCRIPTION
 
+This handler simply displays information about packages in repository.
+
 =head1 METHODS
 
+B<listing>
+
+Lists the packages in both the base installation package repository
+and in the current website package repository.
+
+B<show>
+
+Displays details for a single package.
+
+B<edit>
+
+Edits information for a single package.
+
 =head1 TO DO
 
+B<Ensure editing works>
+
+B<Be able to save more information per package>
+
 =head1 BUGS
 
-A few things do not work in here yet. Need to take a good look at this.
+Need to test this more and shake any out.
 
 =head1 COPYRIGHT
 
