@@ -1,6 +1,6 @@
 package OpenInteract::Handler::Security;
 
-# $Id: Security.pm,v 1.1.1.1 2001/02/02 06:19:59 lachoy Exp $
+# $Id: Security.pm,v 1.3 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use Data::Dumper             qw( Dumper );
@@ -8,7 +8,7 @@ use SPOPS::Secure            qw( :level :scope );
 use SPOPS::Secure::Hierarchy qw( $ROOT_OBJECT_NAME );
 
 @OpenInteract::Handler::Security::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
-$OpenInteract::Handler::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Security::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Security::default_method    = 'simple_show';
@@ -52,17 +52,18 @@ sub hierarchy_show {
   }
   else {
     $object_class = $R->apache->param( 'object_class' );
-    $oid          = $R->apache->param( 'oid' );
+    $oid          = $R->apache->param( 'oid' ) || $R->apache->param( 'object_id' );
   }
 
   # Retrieve the security levels so we can display them
  
   my ( $track, $first, $check_list ) = 
             SPOPS::Secure::Hierarchy->get_hierarchy_levels({ 
-                class => $object_class, oid => $oid,
+                class                 => $object_class, 
+                object_id             => $oid,
                 security_object_class => $R->security_object,
-		        user  => $R->{auth}->{user},
-                group => $R->{auth}->{group},
+		        user                  => $R->{auth}->{user},
+                group                 => $R->{auth}->{group},
             });
 
   my @check_list_items = map { { oid => $_, security_defined => $track->{ $_ } } } 
@@ -98,7 +99,7 @@ sub show {
 
   unless ( $object ) {
     $object_class = $R->apache->param( 'object_class' );
-    $oid          = $R->apache->param( 'oid' );
+    $oid          = $R->apache->param( 'oid' ) || $R->apache->param( 'object_id' );
     if ( $instantiate ne 'no' ) {
       $object = eval { $object_class->fetch( $oid ) };
       if ( ! $object or $@ ) {
@@ -118,10 +119,10 @@ check its <tt>spops.perl</tt> configuration and ensure that
 <tt>SPOPS::Secure</tt> is in the 'isa' tag.
 CANNOTSECURE
     }
-    $R->scrib( 1, "Using object ", ref $object, " (", $object->id, ") for security box editor." ); 
+    $R->DEBUG && $R->scrib( 1, "Using object ", ref $object, " (", $object->id, ") for security box editor." ); 
   }
   else {
-    $R->scrib( 1, "Using class $object_class ($oid) for security box editor." ); 
+    $R->DEBUG && $R->scrib( 1, "Using class $object_class ($oid) for security box editor." ); 
   }
 
   my $params = { main_script  => $MAIN_SCRIPT, 
@@ -136,9 +137,10 @@ CANNOTSECURE
 
   my $security = eval { $R->security_object->fetch_by_object( 
                                  $object, 
-							     { class => $object_class, oid => $oid,
-							       group => 'all' } ) };
-  $R->scrib( 1, "Security fetched: ", Dumper( $security ) );;
+							     { class     => $object_class, 
+                                   object_id => $oid,
+							       group     => 'all' } ) };
+  $R->DEBUG && $R->scrib( 1, "Security fetched: ", Dumper( $security ) );;
   if ( $@ ) {
     my $ei = OpenInteract::Error->set( SPOPS::Error->get );
     $R->throw( { code => 308 } );
@@ -191,7 +193,7 @@ sub edit {
 
   my $level       = $R->apache->param( 'level' );
   my $obj_class   = $R->apache->param( 'object_class' );
-  my $oid         = $R->apache->param( 'oid' );
+  my $oid         = $R->apache->param( 'oid' ) || $R->apache->param( 'object_id' );
   my $instantiate = $R->apache->param( 'instantiate' );
   my @scope       = map { [ split /;/, $_ ] } $R->apache->param( 'scope' );
 
@@ -199,24 +201,24 @@ sub edit {
   my $secure_class = 'SPOPS::Secure';
   foreach my $info ( @scope ) {
     $total++;
-    $R->scrib( 1, "Trying to set security ($level) for $obj_class ($oid) in scope $info->[0] ($info->[1])" );
+    $R->DEBUG && $R->scrib( 1, "Trying to set security ($level) for $obj_class ($oid) in scope $info->[0] ($info->[1])" );
     if ( $level eq 'clear' ) {
       $success += eval { $secure_class->remove_item_security({ 
                              security_object_class => $R->security_object,
-                             class    => $obj_class, 
-                             oid      => $oid,
-                             scope    => $info->[0], 
-                             scope_id => $info->[1],
+                             class     => $obj_class, 
+                             object_id => $oid,
+                             scope     => $info->[0], 
+                             scope_id  => $info->[1],
                         }) };
     }
     else {
       $success += eval { $secure_class->set_item_security({ 
 			                 security_object_class => $R->security_object,
-                             class    => $obj_class, 
-                             oid      => $oid,
-                             scope    => $info->[0], 
-                             scope_id => $info->[1],
-                             level    => $level,
+                             class     => $obj_class, 
+                             object_id => $oid,
+                             scope     => $info->[0], 
+                             scope_id  => $info->[1],
+                             level     => $level,
                         }) };
     }
     if ( $@ ) {
