@@ -1,12 +1,12 @@
 package OpenInteract::Handler::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.1.1.1 2001/02/02 06:20:03 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.4 2001/06/05 14:27:25 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::SiteTemplate::ISA     = qw( OpenInteract::Handler::GenericDispatcher  SPOPS::Secure );
-$OpenInteract::Handler::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::SiteTemplate::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SiteTemplate::default_method    = 'listing';
@@ -15,16 +15,17 @@ $OpenInteract::Handler::SiteTemplate::default_method    = 'listing';
  edit    => SEC_LEVEL_WRITE, remove => SEC_LEVEL_WRITE,
 );
 
-my $DEBUG  = 0;
 my $MAIN_SCRIPT = '/SiteTemplate';
 
+
 sub listing {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $params = { main_script => $MAIN_SCRIPT, error_msg => $p->{error_msg} };
-  $params->{template_list} = eval { $R->site_template->fetch_group({ 
-                                                  order => 'package, name' 
-                                    }) };
+  my $params = { main_script => $MAIN_SCRIPT, 
+                 error_msg   => $p->{error_msg} };
+  $params->{template_list} = eval { $R->site_template->fetch_group({
+                                               order        => 'package, name',
+                                               column_group => 'listing' }) };
   if ( $@ ) {
     OpenInteract::Error->set( SPOPS::Error->get );
     $R->throw( { code => 403 } );
@@ -32,15 +33,16 @@ sub listing {
   }
   
   $R->{page}->{title} = 'Listing of Template Items';
-  return $R->template->handler( {}, $params, { db => 'template_list', 
-                                               package => 'base_template' } );
+  return $R->template->handler( {}, $params, 
+                                { db      => 'template_list', 
+                                  package => 'base_template' } );
 }
 
 sub show {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $params = { main_script => $MAIN_SCRIPT, 
-                 error_msg => $p->{error_msg}, 
+  my $params = { main_script  => $MAIN_SCRIPT, 
+                 error_msg    => $p->{error_msg}, 
                  package_list => $R->CONFIG->{package_list} };
 
   my $template = $p->{template};
@@ -56,13 +58,14 @@ sub show {
 
   if ( ! $template and $p->{level} < SEC_LEVEL_WRITE ) {
     my $user_msg = 'Sorry, you do not have access to create a new template object. Returning to listing.';
-    return $class->listing( { error_msg => $user_msg } );
+    return $class->listing({ error_msg => $user_msg });
   }
 
   # Object security defaults to WRITE: if there is no object,
   # then you're creating it and security then depends on the application
 
-  my $obj_level = ( $template ) ? $template->{tmp_security_level} : SEC_LEVEL_WRITE;
+  my $obj_level = ( $template ) 
+                  ? $template->{tmp_security_level} : SEC_LEVEL_WRITE;
 
   $template  ||= $R->site_template->new;
   $params->{tmpl} = $template;
@@ -71,52 +74,65 @@ sub show {
   foreach my $update_info ( @{ $update_items } ) {
     my $user = eval { $R->user->fetch( $update_info->[0] ) };
     my $username = ( $user ) ? $user->{login_name} : 'admin';
-    push @{ $params->{update_list} }, { login_name => $username, date => $update_info->[1] };
+    push @{ $params->{update_list} }, 
+                 { login_name => $username, 
+                   date       => $update_info->[1] };
   }
 
   my $tmpl_name = 'template_detail';
   if ( $p->{level} == SEC_LEVEL_WRITE and $obj_level == SEC_LEVEL_WRITE ) {
     $tmpl_name = 'template_form';
   }
-  $R->scrib( 1, "Displaying $tmpl_name with template ID $template->{template_id}" );
+  $R->DEBUG && $R->scrib( 1, "Displaying $tmpl_name with template ID $template->{template_id} using shell ($tmpl_name)" );
   $R->{page}->{title} = 'Detail of Template Item';
-  return $R->template->handler( {}, $params, { db => $tmpl_name } ); 
+  return $R->template->handler( {}, $params, 
+                                { db      => $tmpl_name, 
+                                  package => 'base_template' } ); 
 }
 
+
 sub edit {
   my ( $class, $p ) = @_;
   my $R   = OpenInteract::Request->instance;
   my $apr = $R->apache;
   $R->{page}->{return_url} = '/SiteTemplate/';
   my $template_id = $apr->param( 'template_id' );
-  $R->scrib( 1, "Trying to modify ID <<$template_id>>" );
+  $R->DEBUG && $R->scrib( 1, "Trying to modify ID <<$template_id>>" );
   my $template = eval { $R->site_template->fetch( $template_id ); };
   if ( $@ ) {
     OpenInteract::Error->set( SPOPS::Error->get );
     $R->throw( { code => 404 } );
     return $R->listing( { error_msg => 'Cannot retrieve template to modify' } );
   }
-  my $obj_level = ( $template ) ? $template->{tmp_security_level} : SEC_LEVEL_WRITE;
+  my $obj_level = ( $template ) 
+                   ? $template->{tmp_security_level} : SEC_LEVEL_WRITE;
   if ( $obj_level < SEC_LEVEL_WRITE ) {
     my $user_msg = 'Sorry, you do not have access to modify this template object. Returning to listing.';
-    return $class->show( { template => $template, error_msg => $user_msg } );   
+    return $class->show({ template  => $template, 
+                          error_msg => $user_msg });
   }
 
   $template ||= $R->site_template->new;
   my $old_name = $template->{name};
-  foreach my $field ( @{ $R->site_template->field_list } ) {
-    next if ( $field eq 'template_id' );
-    $template->{ $field } = $apr->param( $field );
-  }
+
+  # Assign form values to object
+
+  $template->{name}        = $apr->param( 'name' );
+  $template->{title}       = $apr->param( 'title' );
+  $template->{description} = $apr->param( 'description' );
+  $template->{template}    = $apr->param( 'template' );
+  $template->{script}      = $apr->param( 'script' );
+  $template->{package}     = $apr->param( 'package' );
   if ( my $alt = $apr->param( 'package_alt' ) ) {
     $template->{package} = $alt;   
-    $R->scrib( 1, "Set package to alternate typed in by user." );
+    $R->DEBUG && $R->scrib( 1, "Set package to alternate typed in by user ($alt)" );
   }
   
   eval { $template->save };
   if ( $@ ) {
     warn "Error saving template ($SPOPS::Error::system_msg); trying again.";
-    $template->{name} = ( $old_name ) ? $old_name : $template->generate_random_code( 8 );
+    $template->{name} = ( $old_name ) 
+                         ? $old_name : $template->generate_random_code( 8 );
     eval { $template->save };
     if ( $@ ) {
       $p->{error_msg} = "Error saving template with new name. Please try again.";
@@ -130,18 +146,20 @@ sub edit {
   return $class->listing( $p ); 
 }
 
+
 sub remove {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
   if ( my $template_id = $R->apache->param( 'template_id' ) ) {
     my $template = eval { $R->site_template->fetch( $template_id ) };
     if ( $@ or ! $template ) {
-      return $class->listing( { error_msg => "Cannot remove template: error retrieving template for removal." } );
+      return $class->listing({ 
+                 error_msg => "Cannot remove template: error retrieving template for removal." });
     }
     
     if ( $template->{tmp_security_level} < SEC_LEVEL_WRITE ) {
       my $user_msg = 'Sorry, you do not have access to remove this template object. Returning to listing.';
-      return $class->listing( { error_msg => $user_msg } );   
+      return $class->listing({ error_msg => $user_msg });
     }
     eval { $template->remove };
     if ( $@ ) {
