@@ -1,14 +1,16 @@
 package OpenInteract::Handler::SystemDoc;
 
-# $Id: SystemDoc.pm,v 1.1.1.1 2001/02/02 06:20:42 lachoy Exp $
+# $Id: SystemDoc.pm,v 1.3 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper  qw( Dumper );
 use Pod::Parser;
+use OpenInteract::Package;
+use OpenInteract::PackageRepository;
 
 @OpenInteract::Handler::SystemDoc::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure );
-$OpenInteract::Handler::SystemDoc::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SystemDoc::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::SystemDoc::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SystemDoc::default_method    = 'listing';
@@ -17,16 +19,17 @@ $OpenInteract::Handler::SystemDoc::default_method    = 'listing';
  listing => SEC_LEVEL_READ,  show   => SEC_LEVEL_READ, 
 );
 
+
 use constant MAIN_SCRIPT => '/SystemDoc';
 
 sub listing {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $params = { error_msg => $p->{error_msg}, main_script => MAIN_SCRIPT  };
+  my $params = { error_msg   => $p->{error_msg}, 
+                 main_script => MAIN_SCRIPT  };
   $R->{page}->{title} = 'OpenInteract System Documentation / Menu';
-  return $R->template->handler( {}, 
-                                $params, 
-                                { db => 'system_doc_menu', 
+  return $R->template->handler( {}, $params, 
+                                { db      => 'system_doc_menu', 
                                   package => 'system_doc' } );
 }
 
@@ -35,39 +38,42 @@ sub listing {
 sub package_list {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $params = { error_msg => $p->{error_msg}, main_script => MAIN_SCRIPT };
+  my $params = { error_msg   => $p->{error_msg}, 
+                 main_script => MAIN_SCRIPT };
 
-  # Grab a list of all the packages and find the 'titles' document in
-  # each or read the files directly
+  # Grab the repository for thiw website and fetch a list of all the
+  # packages so we can and find the 'doc/titles' document in each, or
+  # so we can read the files from 'doc/' directly
 
-  my $db_file = join( '/', $R->CONFIG->{dir}->{base}, $OpenInteract::Package::PKG_DB_FILE );
-  $params->{package_list} = eval { OpenInteract::Package->fetch_group({ 
-                                       directory => $R->CONFIG->{dir}->{base} 
-                                   }) };
+  my $repos = OpenInteract::PackageRepository->fetch( 
+                                   undef, 
+                                   { directory => $R->CONFIG->{dir}->{base} } );
+  my $pkg_list   = $repos->fetch_all_packages();
 
 PACKAGE:
-  foreach my $pkg ( @{ $params->{package_list} } ) {
-    $R->scrib( 1, "Finding documents for package $pkg->{name}-$pkg->{version}" );
+  foreach my $pkg ( @{ $pkg_list } ) {
+    $R->DEBUG && $R->scrib( 1, "Finding documents for package $pkg->{name}-$pkg->{version}" );
     my $doc_dir = join( '/', $pkg->{website_dir}, $pkg->{package_dir}, 'doc' );
     unless ( -d $doc_dir ) {
       $doc_dir = join( '/', $pkg->{base_dir}, $pkg->{package_dir}, 'doc' );
       next PACKAGE unless ( -d $doc_dir );
     }
-    $R->scrib( 1, "Found doc dir: $doc_dir" );
+    $R->DEBUG && $R->scrib( 1, "Found doc dir: $doc_dir" );
     if ( -f "$doc_dir/titles" ) {
-      $R->scrib( 1, "Opening titles file in dir" );
+      $R->DEBUG && $R->scrib( 1, "Opening titles file in dir" );
       eval { open( TITLES, "$doc_dir/titles" ) || die $! };
       if ( $@ ) {
-        warn " (SystemDoc/package_list): Error opening titles file; reading filenames directly. (Error: $@)\n";
+        $R->scrib( 0, "Error opening titles file; reading filenames directly. (Error: $@)" );
       }
       else {
         while ( <TITLES> ) {
           chomp;
           next if ( /^\s*\#/ );
           next if ( /^\s*$/ );
-          my ( $filename, $title ) = /^([\w\.]+)\s+(.*)$/;
-          $R->scrib( 1, "Found $filename / $title from $_" );
-          push @{ $pkg->{tmp_doc_list} }, { filename => $filename, title => $title };
+          my ( $filename, $title ) = /^([\w.]+)\s+(.*)$/;
+          $R->DEBUG && $R->scrib( 1, "Found $filename / $title from $_" );
+          push @{ $pkg->{tmp_doc_list} }, 
+                           { filename => $filename, title => $title };
         }
         close( TITLES );
         next PACKAGE;
@@ -75,17 +81,25 @@ PACKAGE:
     }
     eval { opendir( DOC, $doc_dir ) || die $! };
     if ( $@ ) {
-      warn " (SystemDoc/package_list): Could not open $doc_dir: $@\n";
+      $R->scrib( 0, "Could not open $doc_dir: $@" );
       next PACKAGE;
     }
-    my @doc_files = grep { -f "$doc_dir/$_" } grep ! /^(tmp|\.|\_)/, grep ! /~$/, readdir( DOC );
+
+    # Ensure that we get no tmp files and that the file exists
+
+    my @doc_files = grep { -f "$doc_dir/$_" } 
+                    grep ! /^(tmp|\.|\_)/, 
+                    grep ! /~$/, 
+                    readdir( DOC );
     closedir( DOC );
-    $pkg->{tmp_doc_list} = [ map { { filename => $_, title => "$_ (no title)" } } @doc_files ];
+    $pkg->{tmp_doc_list} = [ map { { filename => $_, 
+                                     title    => "$_ (no title)" } } 
+                                 @doc_files ];
   }
+  $params->{package_list} = $pkg_list;
   $R->{page}->{title} = 'OpenInteract Package Documentation';
-  return $R->template->handler( {}, 
-                                $params, 
-                                { db => 'package_doc',
+  return $R->template->handler( {}, $params, 
+                                { db      => 'package_doc',
                                   package => 'system_doc' } );
 }
 
@@ -94,7 +108,8 @@ PACKAGE:
 sub module_list {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $params = { error_msg => $p->{error_msg}, main_script => MAIN_SCRIPT  };
+  my $params = { error_msg   => $p->{error_msg}, 
+                 main_script => MAIN_SCRIPT  };
   my $view = $R->apache->param( 'view' ) || 'local';
 
   # Now sort INC and chop up the files into packages -- depending on
@@ -104,16 +119,19 @@ sub module_list {
   my %this_inc = %INC;
   my @top = ();
   my $website_name = $R->CONFIG->{website_name};
-  $R->scrib( 1, "Website name being filtered: ($website_name)" );
+  $R->DEBUG && $R->scrib( 1, "Website name being filtered: ($website_name)" );
 
   if ( $view eq 'local' ) {
-    @top = ( [ 'OpenInteract', [ 'OpenInteract' ] ], [ 'SPOPS', [ 'SPOPS' ] ], [ $website_name, [] ] );
-    foreach my $local_module ( sort grep /^(OpenInteract|SPOPS|$website_name)/, keys %this_inc ) {
+    @top = ( [ 'OpenInteract', [ 'OpenInteract' ] ], 
+             [ 'SPOPS', [ 'SPOPS' ] ], 
+             [ $website_name, [] ] );
+    my @local_modules = sort grep /^(OpenInteract|SPOPS|$website_name)/, keys %this_inc;
+    foreach my $local_module ( @local_modules ) {
       my ( $module_type ) = $local_module =~ /^(\w+)\//;
       push @{ $top[0]->[1] }, _colonify( $local_module )  if ( $module_type eq 'OpenInteract' );
       push @{ $top[1]->[1] }, _colonify( $local_module )  if ( $module_type eq 'SPOPS' );
       push @{ $top[2]->[1] }, _colonify( $local_module )  if ( $module_type eq $website_name );
-      $R->scrib( 1, "Found package $local_module ($module_type)" );
+      $R->DEBUG && $R->scrib( 1, "Found package $local_module ($module_type)" );
     }
   }
   elsif ( $view eq 'general' ) {
@@ -131,27 +149,25 @@ sub module_list {
       my ( $first ) = split /\//, $full_pkg;
       if ( $first ne $curr_parent ) {
         $count++;
-        $R->scrib( 1, "First item != parent: ($first) / ($curr_parent)" );
+        $R->DEBUG && $R->scrib( 1, "First item != parent: ($first) / ($curr_parent)" );
         $curr_parent   = $first;
         $curr_parent   =~ s/\.pm$//;
         $top[ $count ] = [ $curr_parent, [] ]; #  _colonify( $curr_parent ) 
       }
-      $R->scrib( 1, "Found package $full_pkg" );
+      $R->DEBUG && $R->scrib( 1, "Found package $full_pkg" );
       push @{ $top[ $count ]->[1] }, _colonify( $full_pkg );
     }
   }
   $params->{module_list}  = \@top;
-  $R->scrib( 1, "Number of module parents found: ", scalar @top );
+  $R->DEBUG && $R->scrib( 1, "Number of module parents found: ", scalar @top );
   
   $R->{page}->{title} = 'OpenInteract System Documentation / Module Documentation';
-  return $R->template->handler( {}, 
-                                $params, 
-                                { db => 'system_module_listing',
+  return $R->template->handler( {}, $params, 
+                                { db      => 'system_module_listing',
                                   package => 'system_doc' } );
 }
 
 
-
 sub _colonify {
   my ( $text ) = @_;
   $text =~ s|\.pm$||;
@@ -171,21 +187,20 @@ sub _uncolonify {
 sub show {
   my ( $class, $p ) = @_;
   my $R = OpenInteract::Request->instance;
-  my $package = $R->apache->param( 'package' );
 
   my ( $pod_file, $html_file, $text_file );
 
   # If this is a package, display the doc
 
+  my $package = $R->apache->param( 'package' );
   if ( $package ) {
     my $doc = $R->apache->param( 'doc' );
-    my $pkg = OpenInteract::Package->fetch_by_name({ 
-                   name => $package, 
-                   directory => $R->CONFIG->{dir}->{base}
-              });
+    my $repos = OpenInteract::PackageRepository->fetch( 
+                                   undef, 
+                                   { directory => $R->CONFIG->{dir}->{base} } );
     if ( $doc =~ /\.(html|txt|pod)$/ ) {
-      my $full_filename = $pkg->find_file( "doc/$doc" );
-      $R->scrib( 1, "Found ($full_filename) using $doc and $package" );
+      my $full_filename = $repos->find_file( $package, "doc/$doc" );
+      $R->DEBUG && $R->scrib( 1, "Found ($full_filename) using $doc and $package" );
       $pod_file  = $full_filename  if ( $doc =~ /\.pod$/ );
       $html_file = $full_filename  if ( $doc =~ /\.html$/ );
       $text_file = $full_filename  if ( $doc =~ /\.txt$/ );
@@ -193,24 +208,26 @@ sub show {
   }
   else {
     my $module = $p->{module} || $R->apache->param( 'module' );
-    $pod_file = `perldoc -l $module`;
+    $pod_file = `perldoc -l $module`; # ewww! ick! 
     chomp $pod_file;
-    $R->scrib( 1, "Found ($pod_file) from module ($module)" );
+    $R->DEBUG && $R->scrib( 1, "Found ($pod_file) from module ($module)" );
     unless ( $pod_file ) {
       $pod_file = $INC{ _uncolonify( $module ) };   
-      $R->scrib( 1, "Found ($pod_file) from module ($module)" );
+      $R->DEBUG && $R->scrib( 1, "Found ($pod_file) from module ($module)" );
     }
   }
+
   if ( -f $pod_file ) {
-    $R->scrib( 1, "Trying to view pod in $pod_file" );
+    $R->DEBUG && $R->scrib( 1, "Trying to view pod in $pod_file" );
     chdir( '/tmp' );
-    my $pod_text = `pod2html $pod_file`;
+    my $pod_text = `pod2html $pod_file`; # ewww! ick! 
     $pod_text =~ s/^.*<BODY>//;
     $pod_text =~ s|</BODY>.*$||;
-    return '<p>Sorry, no docs for this module.' unless $pod_text;
+    return '<p>Sorry, no docs for this module.' unless ( $pod_text );
     $R->{page}->{title} = 'OpenInteract System Documentation Display';
     return $pod_text;
   } 
+
   if ( -f $html_file ) {
     eval { open( HTML, $html_file ) || die $! };
     return "<p>Error opening HTML file: $@"  if ( $@ );
@@ -219,21 +236,22 @@ sub show {
     close( HTML );
     $html_text =~ s/^.*<BODY>//;
     $html_text =~ s|</BODY>.*$||;
-    return '<p>Sorry, no docs for this module.' unless $html_text;
+    return '<p>Sorry, no docs for this module.' unless ( $html_text );
     $R->{page}->{title} = 'OpenInteract System Documentation Display';
     return $html_text;
   }
+
   if ( -f $text_file ) {
     eval { open( TEXT, $text_file ) || die $! };
     return "<p>Error opening TEXT file: $@"  if ( $@ );
     local $/ = undef;
     my $text_text = <TEXT>;
     close( TEXT );
-    return '<p>Sorry, no docs for this module.' unless $text_text;
+    return '<p>Sorry, no docs for this module.' unless ( $text_text );
     $R->{page}->{title} = 'OpenInteract System Documentation Display';
     return qq(<pre><font size="-1">$text_text</font></pre>);
   }
-  return '<p>Sorry, I cannot find documentation by that name';
+  return '<p>Sorry, I cannot find documentation by that name.</p>';
 }
 
 1;
@@ -278,8 +296,6 @@ Parameters:
    Perl module to extract POD from; we match up the module to a file
    using %INC
 
-=head1 NOTES
-
 =head1 TO DO
 
 B<Get more meta information>
