@@ -1,12 +1,12 @@
 package OpenInteract::Handler::User;
 
-# $Id: User.pm,v 1.1.1.1 2001/02/02 06:20:20 lachoy Exp $
+# $Id: User.pm,v 1.2 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level :scope );
 
 @OpenInteract::Handler::User::ISA     = qw( OpenInteract::Handler::GenericDispatcher  SPOPS::Secure );
-$OpenInteract::Handler::User::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::User::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::User::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::User::default_method    = 'listing';
@@ -71,7 +71,7 @@ sub show {
                    : SEC_LEVEL_WRITE;
 
   $params->{user} ||= $R->user->new( { theme_id => $R->{theme}->{theme_id} } );
-  $R->scrib( 1, "Levels  $params->{user}->{user_id}: $obj_level/$p->{level}" );
+  $R->DEBUG && $R->scrib( 1, "Levels  $params->{user}->{user_id}: $obj_level/$p->{level}" );
   $params->{group_list} = eval { $params->{user}->group };
 
   my $tmpl_name = 'user_detail';
@@ -92,7 +92,7 @@ sub edit {
   my $apr = $R->apache;
 
   my $user_id = $apr->param( 'user_id' );
-  $R->scrib( 1, "Trying to modify ID <<$user_id>>" );
+  $R->DEBUG && $R->scrib( 1, "Trying to modify ID <<$user_id>>" );
   
   my $is_new = 0;
   my $user = $p->{user} ||
@@ -126,7 +126,7 @@ sub edit {
   }
   my $password = $apr->param( 'password' );
   if ( $password ) {
-    $R->scrib( 1, "User asked to change password. Changing." );
+    $R->DEBUG && $R->scrib( 1, "User asked to change password. Changing." );
     $password = $R->user->crypt_it( $password ) if ( $R->CONFIG->{login}->{crypt_password} );;
     $user->{password} = $password;
   }
