@@ -1,15 +1,16 @@
 package OpenInteract::Session;
 
-# $Id: Session.pm,v 1.2 2001/02/21 13:10:03 lachoy Exp $
+# $Id: Session.pm,v 1.5 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 use Data::Dumper qw( Dumper );
 
 @OpenInteract::Session::ISA     = ();
-$OpenInteract::Session::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Session::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Session::COOKIE_NAME = 'session';
 
+
 sub parse { 
   my ( $class, $session_id ) = @_;
   my $R     = OpenInteract::Request->instance;
@@ -20,7 +21,7 @@ sub parse {
   # create a new session
 
   unless ( $session_id ) {
-    $R->scrib( 1, "No session_id found. Skipping session_init..." );
+    $R->DEBUG && $R->scrib( 1, "No session_id found. Skipping session_init..." );
     $R->{session} = {};
     return undef;
   }
@@ -29,7 +30,7 @@ sub parse {
     $R->{session} = {};
     return undef;
   }
-  $R->scrib( 2, "Retrieved session properly: ", Dumper( $R->{session} ) );
+  $R->DEBUG && $R->scrib( 2, "Retrieved session properly: ", Dumper( $R->{session} ) );
   return 1;
 }
 
@@ -39,13 +40,13 @@ sub save {
   my $R     = OpenInteract::Request->instance;
   if ( tied %{ $R->{session} } ) {
     $R->{session}->{timestamp} = $R->{time};
-    $R->scrib( 2, "Saving tied session\n", Dumper( $R->{session} ) );
+    $R->DEBUG && $R->scrib( 2, "Saving tied session\n", Dumper( $R->{session} ) );
     untie %{ $R->{session} };
   }
   elsif ( ref( $R->{session} ) ) {
-    $R->scrib( 1, "Session not yet created. Creating..." );
+    $R->DEBUG && $R->scrib( 1, "Session not yet created. Creating..." );
     unless ( scalar keys %{ $R->{session} } ) {
-      $R->scrib( 1, "No session information saved. Exiting..." );
+      $R->DEBUG && $R->scrib( 1, "No session information saved. Exiting..." );
       return 1;
     }   
     my $session = $class->_create_session;
@@ -59,21 +60,24 @@ sub save {
       my ( $expiration );
       if ( exists $R->{session}->{expiration} ) {
         $expiration = $R->{session}->{expiration};
+        $R->DEBUG && $R->scrib( 1, "Expiration for new session manually set to ($expiration)" );
         delete $R->{session}->{expiration};
       }
       else {
         $expiration = $R->CONFIG->{session_info}->{expiration};
+        $R->DEBUG && $R->scrib( 1, "Expiration for new session set to default from config ($expiration)" );
       }
 
       # Set the session values
+
       foreach my $key ( keys %{ $R->{session} } ) {
         $session->{ $key } = $R->{session}->{ $key };
       }
-      $R->cookies->create_cookie( { name => $OpenInteract::Session::COOKIE_NAME, 
-                                    value => $session->{_session_id},
-                                    path => '/', 
-                                    expires => $expiration } );
-      $R->scrib( 2, "Saving new session\n", Dumper( $session ) );
+      $R->cookies->create_cookie({ name    => $OpenInteract::Session::COOKIE_NAME, 
+                                   value   => $session->{_session_id},
+                                   path    => '/', 
+                                   expires => $expiration });
+      $R->DEBUG && $R->scrib( 2, "Saving new session\n", Dumper( $session ) );
       untie %{ $session };
     }
     else {
@@ -156,8 +160,12 @@ so now if there is information in {session}
 
 =head1 TO DO
 
+Nothing
+
 =head1 BUGS
 
+None known.
+
 =head1 SEE ALSO
 
 L<Apache::Session>
