@@ -1,31 +1,24 @@
 package OpenInteract::Session::MySQL;
 
-# $Id: MySQL.pm,v 1.2 2001/02/21 13:10:04 lachoy Exp $
+# $Id: MySQL.pm,v 1.5 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 
 @OpenInteract::Session::MySQL::ISA     = qw( OpenInteract::Session );
-$OpenInteract::Session::MySQL::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Session::MySQL::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 sub _create_session { 
   my ( $class, $session_id ) = @_;
   my $R     = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to fetch session $session_id" );
+  $R->DEBUG && $R->scrib( 1, "Trying to fetch session $session_id" );
   my %session = ();
   eval { tie %session, 'Apache::Session::MySQL', $session_id, 
                        { Handle => $R->db, LockHandle => $R->db } };
   if ( $@ ) {
-    $R->scrib( 0, "Cannot create session -- someone is probably using ",
-                  "a defunct key or something." );
-    $R->throw( { code => 310, type => 'session',
+    $R->throw( { code       => 310, type => 'session',
                  system_msg => $@,
-                 extra => { class => 'Apache::Session::MySQL', 
-                            session_id => $session_id } } );
-    $R->scrib( 0, "Error thrown. Now clear the cookie" );
-    $R->cookies->create_cookie( { name => $OpenInteract::Session::COOKIE_NAME,
-                                  path => '/',
-                                  value => undef,
-                                  expires => '-3d' } );
+                 extra      => { class => 'Apache::Session::MySQL', 
+                                 session_id => $session_id } } );
     return undef;
   }
   return \%session;
@@ -46,12 +39,24 @@ OpenInteract::Session::MySQL - Create sessions within MySQL
 Provide a '_create_session' method for L<OpenInteract::Session> so we
 can use MySQL as a backend for L<Apache::Session>.
 
+Note that failure to create the session throws a '310' error, which
+clears out the session cookie so it does not keep happening. (See
+L<OpenInteract::Error::System> for the code.)
+
+=head1 METHODS
+
+B<_create_session( $session_id )>
+
+Overrides the method from parent C<OpenInteract::Session>.
+
 =head1 BUGS 
 
-None yet!
+None known.
 
 =head1 TO DO
 
+Nothing.
+
 =head1 SEE ALSO
 
 L<Apache::Session>, L<Apache::Session::MySQL>
