@@ -1,13 +1,13 @@
 package OpenInteract::Template;
 
-# $Id: Template.pm,v 1.2 2001/02/21 13:10:03 lachoy Exp $
+# $Id: Template.pm,v 1.3 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
 use SPOPS::Secure qw( :level :scope );
 
 @OpenInteract::Template::ISA     = ();
-$OpenInteract::Template::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Template::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 my $SECURITY_CONSTANTS  = {
  level => {
@@ -35,11 +35,11 @@ sub default_info {
   if ( $R->{theme} ) {
     $R->{theme_values}  ||= $R->{theme}->all_values;
     $info->{th}           = $R->{theme_values};
-    $R->scrib( 2, "Theme values = ", Dumper( $info->{th} ) );
+    $R->DEBUG && $R->scrib( 2, "Theme values = ", Dumper( $info->{th} ) );
   }
   $info->{error_hold}   = $R->{error_hold};
   $info->{session}      = \%{ $R->{session} };
-  $R->scrib( 2, "Contents of default info:", Dumper( $info ) );
+  $R->DEBUG && $R->scrib( 2, "Contents of default info:", Dumper( $info ) );
   return $class->_default_info( $info );
 }
 
@@ -73,7 +73,7 @@ sub read_template {
   # See if database reference was passed in
 
   elsif ( $p->{db} ) {
-    $R->scrib( 1, "Trying to read template with DB tag: <<$p->{db}>> and package <<$p->{package}>>" );
+    $R->DEBUG && $R->scrib( 1, "Trying to read template with DB tag: <<$p->{db}>> and package <<$p->{package}>>" );
     my $template = eval { $R->site_template->fetch_by_name( $p->{db}, 
                                                             $p->{package} ) };
     if ( $@ or ! $template ) {
@@ -85,8 +85,8 @@ sub read_template {
       $p->{file} = $p->{db}; 
     }
     else { 
-      $R->scrib( 1, "Fetched template object ok" );
-      $R->scrib( 3, "Detail:", Dumper( $template ) ); 
+      $R->DEBUG && $R->scrib( 1, "Fetched template object ok" );
+      $R->DEBUG && $R->scrib( 3, "Detail:", Dumper( $template ) ); 
 
       # Track the template object for later
 
@@ -106,7 +106,7 @@ sub read_template {
   if ( ! $text and $p->{file} ) {
     my $filename = $class->process_filename({ file => $p->{file}, 
                                               package => $p->{package} });
-    $R->scrib( 1, "Filename retrieved from processing: ($filename)" );
+    $R->DEBUG && $R->scrib( 1, "Filename retrieved from processing: ($filename)" );
     unless ( $filename ) {
       return $R->throw( { code => 201, type => 'template',
                           system_msg => "No proper filename to open for template",
@@ -118,7 +118,7 @@ sub read_template {
                           system_msg => "Failed to open filename. Error: $@",
                           extra => { filename => $filename } } );
     }
-    $R->scrib( 1, "File opened ok. Reading." );
+    $R->DEBUG && $R->scrib( 1, "File opened ok. Reading." );
     local $/ = undef;
     $text = <TEXT>;
     $tag  = $p->{file};
