@@ -1,6 +1,6 @@
 package OpenInteract::Template::Toolkit;
 
-# $Id: Toolkit.pm,v 1.1.1.1 2001/02/02 06:19:20 lachoy Exp $
+# $Id: Toolkit.pm,v 1.3 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use Data::Dumper   qw( Dumper );
@@ -9,7 +9,7 @@ use HTML::Entities ();
 use SPOPS::Utility ();
 
 @OpenInteract::Template::Toolkit::ISA     = qw( OpenInteract::Template );
-$OpenInteract::Template::Toolkit::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Template::Toolkit::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 
 # Map all the subroutines to a name -- the name is how you call it in
@@ -40,10 +40,10 @@ my %UTILS = (
 sub handler {
   my ( $class, $template_config, $template_vars, $template_source ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 3, "Parameters passed in:\n", "Config: ", Dumper( $template_config ), "\n", 
+  $R->DEBUG && $R->scrib( 3, "Parameters passed in:\n", "Config: ", Dumper( $template_config ), "\n", 
                 "Vars:   ", Dumper( $template_vars ), "\n", 
                 "Other:  ", Dumper( $template_source ) );
-  $R->scrib( 2, "Parameter names passed in:\n", 
+  $R->DEBUG && $R->scrib( 2, "Parameter names passed in:\n", 
                 "Config: ", join( ' // ', keys %{ $template_config } ), "\n", 
                 "Vars: ", join( ' // ', keys %{ $template_vars } ), "\n", 
                 "Other: ", join( ' // ', keys %{ $template_source } ) );
@@ -76,8 +76,8 @@ sub handler {
                        system_msg => $template->error(), 
                        extra => { filename => $template_source } });
   }
-  $R->scrib( 1, "Template processing went ok. Returning html." );
-  $R->scrib( 3, "Resulting html:\n$html" );
+  $R->DEBUG && $R->scrib( 1, "Template processing went ok. Returning html." );
+  $R->DEBUG && $R->scrib( 3, "Resulting html:\n$html" );
   return $html;
 }
 
@@ -140,7 +140,7 @@ sub comp {
   # Pass the information to the component processor
   
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Calling template component ($name)" );
+  $R->DEBUG && $R->scrib( 1, "Calling template component ($name)" );
   return $R->component->handler( $p );
 }
 
@@ -149,7 +149,7 @@ sub comp {
 sub limit_string { 
   my ( $str, $len ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 2, "limiting $str to $len characters" );
+  $R->DEBUG && $R->scrib( 2, "limiting $str to $len characters" );
   return $str if ( length $str <= $len ); 
   return substr( $str, 0, $len ) . '...';
 }
@@ -161,9 +161,9 @@ sub limit_string {
 sub regex_chunk {
   my ( $str, $match ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 2, "Grabbing the match ($match) from string (($str))" );
+  $R->DEBUG && $R->scrib( 2, "Grabbing the match ($match) from string (($str))" );
   my ( $item ) = $str =~ /$match/m;
-  $R->scrib( 2, "Matched (($item)) from string." );
+  $R->DEBUG && $R->scrib( 2, "Matched (($item)) from string." );
   return $item;
 }
 
@@ -180,7 +180,7 @@ sub box_add {
   my ( $box, $params ) = @_;
   $params ||= {};
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to add $box with ", Dumper( $params ) );
+  $R->DEBUG && $R->scrib( 1, "Trying to add $box with ", Dumper( $params ) );
   push @{ $R->{boxes} }, { name => $box, params => $params };
   return undef;
 }
@@ -232,7 +232,7 @@ sub date_into_hash {
 sub simulate_sprintf {
   my ( $pat, @nums ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to sprintf with $pat and @nums" );
+  $R->DEBUG && $R->scrib( 1, "Trying to sprintf with $pat and @nums" );
   return sprintf( "$pat", @nums );
 }
 
@@ -243,7 +243,7 @@ sub percent_format {
   my ( $num, $places ) = @_;
   $places ||= 2;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to format $num as a percent" );
+  $R->DEBUG && $R->scrib( 1, "Trying to format $num as a percent" );
   my $pat = "%5.${places}f%%";
   return sprintf( $pat, $num * 100 );
 }
@@ -254,7 +254,7 @@ sub percent_format {
 sub money_format {
   my ( $num ) = @_;
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to format $num as money" );
+  $R->DEBUG && $R->scrib( 1, "Trying to format $num as money" );
   return sprintf( '$%5.2f', $num );
 }
 
@@ -265,7 +265,7 @@ sub object_info {
   my ( $obj ) = @_;
   return {} unless ( ref $obj );
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 2, "Object info: ", ref $obj, " (", $obj->id, ")" );
+  $R->DEBUG && $R->scrib( 2, "Object info: ", ref $obj, " (", $obj->id, ")" );
   return { class => ref $obj, oid => $obj->id, %{ $obj->object_description } };
 }
 
