@@ -1,6 +1,6 @@
 package OpenInteract::UI::Main;
 
-# $Id: Main.pm,v 1.1.1.1 2001/02/02 06:19:21 lachoy Exp $
+# $Id: Main.pm,v 1.2 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 
@@ -18,18 +18,18 @@ sub handler {
   if ( my $directive = $R->{ui}->{directive} ) { 
     if ( $directive =~ /^(NoTmpl|NoTemplate)$/ ) {
       $R->{page}->{_no_template_}++;
-      $R->scrib( 1, "Using NO window template" );
+      $R->DEBUG && $R->scrib( 1, "Using NO window template" );
     }
     else {
       $R->{page}->{_template_key_} = $R->CONFIG->{page_directives}->{ $directive };
-      $R->scrib( 1, "Using template key from directive: ($R->{page}->{_template_key_})" );
+      $R->DEBUG && $R->scrib( 1, "Using template key from directive: ($R->{page}->{_template_key_})" );
     }
   }
   
   # Parse the URL and the information for our first action
   
   my ( $action_class, $action_method ) = $R->lookup_action;
-  $R->scrib( 1, "Action info: $action_class / $action_method" );
+  $R->DEBUG && $R->scrib( 1, "Action info: $action_class / $action_method" );
   
   # Capture any die() commands thrown; note that any error handler that
   # throws a die() needs to also return content to display; otherwise
@@ -57,7 +57,7 @@ sub handler {
   my $db_template_name = $R->{page}->{_template_name_} || 
                          $R->{theme}->property_value( $template_key );
 
-  $R->scrib( 1, "Using template <<$db_template_name>> for full page" );
+  $R->DEBUG && $R->scrib( 1, "Using template <<$db_template_name>> for full page" );
   $R->{main_template_vars} ||= {};
   
   return $R->template->handler( {}, 
