@@ -1,11 +1,11 @@
 package OpenInteract::User;
 
-# $Id: User.pm,v 1.1.1.1 2001/02/02 06:20:18 lachoy Exp $
+# $Id: User.pm,v 1.2 2001/05/30 03:13:03 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level :scope );
 
-$OpenInteract::User::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::User::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::User::crypt_password = undef;
 
 
@@ -13,7 +13,7 @@ sub _class_initialize {
   my ( $class, $CONFIG ) = @_;
   no strict 'refs';
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Set $class to use crypt ($CONFIG->{login}->{crypt_password})" );
+  $R->DEBUG && $R->scrib( 1, "Set $class to use crypt ($CONFIG->{login}->{crypt_password})" );
   ${ $class . '::crypt_password' } = $CONFIG->{login}->{crypt_password};
 }
 
@@ -79,7 +79,7 @@ sub check_password {
   my $class = ref $self;
   my $use_crypt = ${ $class . '::crypt_password' };
   if ( $use_crypt ) {
-    $R->scrib( 1, "Checking using the crypt() function." );
+    $R->DEBUG && $R->scrib( 1, "Checking using the crypt() function." );
     return ( crypt( $check_pw, $exist_pw ) eq $exist_pw );
   } 
   return ( $check_pw eq $exist_pw );
