@@ -1,6 +1,6 @@
 package OpenInteract::User::AuthSmb;
 
-# $Id: AuthSmb.pm,v 1.1.1.1 2001/02/02 06:20:21 lachoy Exp $
+# $Id: AuthSmb.pm,v 1.2 2001/05/30 03:13:03 lachoy Exp $
 
 # Note: You MUST specify OpenInteract::User in your object's 'isa'
 
@@ -15,7 +15,7 @@ use constant SMB_SERVER_ERROR   => 1;
 use constant SMB_PROTOCOL_ERROR => 2;
 use constant SMB_LOGON_ERROR    => 3;
 
-$OpenInteract::User::AuthSmb::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::User::AuthSmb::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
 
 sub check_password {
   my ( $self, $check_pw ) = @_;
@@ -25,7 +25,7 @@ sub check_password {
   my $BDC    = $conf->{smb_bdc};
   my $DOMAIN = $conf->{smb_domain};
   my $R = OpenInteract::Request->instance;
-  $R->scrib( 1, "Trying to check SMB password for ($self->{login_name} using",
+  $R->DEBUG && $R->scrib( 1, "Trying to check SMB password for ($self->{login_name} using",
                 "PDC: $PDC - BDC: $BDC - DOMAIN - $DOMAIN" );
   my $rv = Authen::Smb::authen( $self->{login_name}, $check_pw,
                                 $PDC, $BDC, $DOMAIN );
@@ -36,7 +36,7 @@ sub check_password {
   $error_status = "Protocol Error"  if ( $rv == SMB_PROTOCOL_ERROR );
   $R->scrib( 0, "Error found trying to login: $error_status" );
   if ( $conf->{smb_use_internal_auth} ) {
-    $R->scrib( 1, "Internal password being checked since SMB check failed." );
+    $R->DEBUG && $R->scrib( 1, "Internal password being checked since SMB check failed." );
     return $self->SUPER::check_password( $check_pw );
   }
   return undef; 
