@@ -1,12 +1,12 @@
 package OpenInteract::Utility;
 
-# $Id: Utility.pm,v 1.1.1.1 2001/02/02 06:19:13 lachoy Exp $
+# $Id: Utility.pm,v 1.3 2001/05/30 03:13:02 lachoy Exp $
 
 use strict;
 use Mail::Sendmail ();
 
 @OpenInteract::Utility::ISA     = ();
-$OpenInteract::Utility::VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Utility::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEBUG  => 0;
 
@@ -20,8 +20,8 @@ sub send_email {
     message => $p->{message},
     smtp    => $p->{smtp}    || $R->CONFIG->{smtp_host},
   );
-  $R->scrib( 1, "Trying to send  to <<$p->{email}>>" );
-  $R->scrib( 2, "Message being sent:\n$p->{message}" );
+  $R->DEBUG && $R->scrib( 1, "Trying to send  to <<$p->{email}>>" );
+  $R->DEBUG && $R->scrib( 2, "Message being sent:\n$p->{message}" );
   eval { Mail::Sendmail::sendmail( %mail ) || die $Mail::Sendmail::error };
   if ( $@ ) {
     my $msg = "Cannot send email. Error: $@";
@@ -67,8 +67,8 @@ Sends an email with the parameters you specify.
 On success: returns a true value;
 
 On failure: dies with general error message ('Cannot send email:
-<error>') and sets typical messages in OpenInteract::Error, including the
-following parameters in {extra}:
+<error>') and sets typical messages in OpenInteract::Error, including
+the following parameters in {extra}:
 
  - subject: subject of email
  - from: who is the email from (will use the admin email if not specified)
@@ -77,8 +77,10 @@ following parameters in {extra}:
 
 Example:
 
- eval { OpenInteract::Utility->send_mail( { to => 'santa@xmas.com', subject => 'gimme!',
-                                        message => join "\n", @xmas_list } ) };
+ eval { OpenInteract::Utility->send_mail({ 
+                         to      => 'santa@xmas.com', 
+                         subject => 'gimme!',
+                         message => join "\n", @xmas_list }) };
  if ( $@ ) {
    my $ei = OpenInteract::Error->get;
    carp "Failed to send an email! Error: $ei->{system_msg}\n",
