@@ -5,7 +5,7 @@ CREATE TABLE template (
  description   text null,
  template      text not null,
  script        text null,
- package       varchar(40) null,
+ package       varchar(40) not null,
  primary key   ( template_id ),
  unique        ( name, package )
 )
\ No newline at end of file
